//////////////////////////////////////////////////////////////////////////////
// * File name: main.c
// *                                                                          
// * Description:  Main function.
// *                                                                          
// * Copyright (C) 2010 Texas Instruments Incorporated - http://www.ti.com/ 
// * Copyright (C) 2010 Spectrum Digital, Incorporated
// *                                                                          
// *                                                                          
// *  Redistribution and use in source and binary forms, with or without      
// *  modification, are permitted provided that the following conditions      
// *  are met:                                                                
// *                                                                          
// *    Redistributions of source code must retain the above copyright        
// *    notice, this list of conditions and the following disclaimer.         
// *                                                                          
// *    Redistributions in binary form must reproduce the above copyright     
// *    notice, this list of conditions and the following disclaimer in the   
// *    documentation and/or other materials provided with the                
// *    distribution.                                                         
// *                                                                          
// *    Neither the name of Texas Instruments Incorporated nor the names of   
// *    its contributors may be used to endorse or promote products derived   
// *    from this software without specific prior written permission.         
// *                                                                          
// *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS     
// *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT       
// *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR   
// *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT    
// *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,   
// *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT        
// *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,   
// *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY   
// *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT     
// *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE   
// *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.    
// *                                                                          
//////////////////////////////////////////////////////////////////////////////
 
#include "dma.h"
#include "timer.h"
#include "rtc.h"
#include "i2s.h"

#include "csl_pll.h"
#include "cslr_sysctrl.h"
#include "cslr_cpu.h"
#include "soc.h"
#include "csl_intc.h"

#include "aic3204.h"
#include "usbstk5505_led.h"
#include "stdio.h"

void InitSystem(void);
void ConfigPort(void);
void SYS_GlobalIntEnable(void);
void SYS_GlobalIntDisable(void);
void BlinkLED(void);
void GenerateAudioTone(void);

Uint16 fSineWave = 0;
Uint16 f1KToneOn =0;
Uint16 f2KToneOn =0;

extern Uint16 fTimer;
extern Uint16 Flag_RTC;
extern Uint16 Count_RTC;
extern Uint16 halfSecCnt;

/* 
 *  main( )
 *
 */
void main(void)
{
    InitSystem();
    ConfigPort();

    SYS_GlobalIntEnable();

    IRQ_enable(TINT_EVENT);  // Enable timer int
    IRQ_enable(RTC_EVENT);   // Enable RTC int

    Timer0Init();
    reset_RTC();
    enable_rtc_second_int();

    AIC3204_init( );
    I2S_init( );
    
    while(1)
    {
        BlinkLED();
        GenerateAudioTone();
    }
}

PLL_Obj pllObj;

/*
 *  InitSystem( )
 *      Setup PLL and reset peripherals
 */
void InitSystem(void)
{
    Uint16 i;
    CSL_Status status;
    PLL_Handle hPll;
    PLL_Config *pConfigInfo;
    
    /* VC505 */
    //PLL_Config pllCfg_v1_40MHz     = {0x8262, 0x8000, 0x0806, 0x0300};
    //PLL_Config pllCfg_v1_60MHz     = {0x81C8, 0xB000, 0x0806, 0x0000};
    //PLL_Config pllCfg_v1_75MHz     = {0x823B, 0x9000, 0x0806, 0x0000};
    PLL_Config pllCfg_v1_100MHz    = {0x82FA, 0x8000, 0x0806, 0x0000};
    //PLL_Config pllCfg_v1_120MHz    = {0x8392, 0xA000, 0x0806, 0x0000};
    /* C5505/5515 */
    //PLL_Config pllCfg_v2_40MHz     = {0x8988, 0x8000, 0x0806, 0x0201};
    //PLL_Config pllCfg_v2_60MHz     = {0x8724, 0x8000, 0x0806, 0x0000};
    //PLL_Config pllCfg_v2_75MHz     = {0x88ED, 0x8000, 0x0806, 0x0000};
    PLL_Config pllCfg_v2_100MHz    = {0x8BE8, 0x8000, 0x0806, 0x0000};
    //PLL_Config pllCfg_v2_120MHz    = {0x8E4A, 0x8000, 0x0806, 0x0000};

    status = PLL_init(&pllObj, CSL_PLL_INST_0);
    if(CSL_SOK != status)
    {
       printf("PLL init failed \n");
       return;
    }
    hPll = (PLL_Handle)(&pllObj);
    PLL_reset(hPll);
    /* Configure the PLL for 100MHz */
    if (CSL_SYSCTRL_REGS->DIEIDR3 & 0xF000)
        pConfigInfo = &pllCfg_v1_100MHz;
    else
        pConfigInfo = &pllCfg_v2_100MHz;

    status = PLL_config (hPll, pConfigInfo);
    if(CSL_SOK != status)
    {
        printf("PLL config failed\n");
        return;
    }

    /* Reset peripherals */
    CSL_FINS(CSL_SYSCTRL_REGS->PSRCR, SYS_PSRCR_COUNT,
                     0x02);
    CSL_SYSCTRL_REGS->PRCR = 0xfb;
    
    /* Delay for devices to reset */
    for (i=0; i< 200; i++);
}

/*
 *  ConfigPort( )
 *      Configure port modes
 */
void ConfigPort(void)
{
    /* Configure ports*/
    /* Set Serial port 0 for mode 2 */
    CSL_FINST(CSL_SYSCTRL_REGS->EBSR, SYS_EBSR_SP0MODE, MODE1);
    
    /* Set Serial port 1 for mode 1 */
    CSL_FINST(CSL_SYSCTRL_REGS->EBSR, SYS_EBSR_SP1MODE, MODE2);
    
    /* Set parallel port mode for mode 6 */
    CSL_FINST(CSL_SYSCTRL_REGS->EBSR, SYS_EBSR_PPMODE,MODE6);
    
    /* Set A20_MODE for GPIO mode */
    CSL_FINST(CSL_SYSCTRL_REGS->EBSR, SYS_EBSR_A20_MODE, MODE1);
}

/*
 *  SYS_GlobalIntEnable( )
 *      Enable interrupts
 */
void SYS_GlobalIntEnable(void)
{
    IRQ_globalEnable();
}

/*
 *  SYS_GlobalIntDisable( )
 *      Disable interrupts
 */
void SYS_GlobalIntDisable(void)
{
    IRQ_globalDisable();
}

/*
 *  toggleLED( )
 *      Change LED to the opposite state
 */
static toggleLED(void)
{
    Uint16 temp;

    temp = USBSTK5505_LED_get();
    if(temp)
    {
        /* Turn off LED */
        USBSTK5505_LED_off( );
    }
    else
    {
        /* Turn on LED */
        USBSTK5505_LED_on ( );
    }
}

/*
 *  BlinkLED( )
 *      Toggle LED depending on state
 */
void BlinkLED(void)
{
    if(fSineWave==1)
    {
        if(Flag_RTC ==1)
        {
            Flag_RTC =0;
            toggleLED();
        }
    }
    else
    {
        if(fTimer ==1)
        {
            fTimer =0;
            toggleLED();
        }
    }
}

/*
 *  GenerateAudioTone( )
 *      Setup DMA for sinewave (frequency depends on state)
 */
void GenerateAudioTone(void)
{
    if(Count_RTC < 10)
    {
        if(f1KToneOn ==1)
            return;
            
        /* 1KHz sine wave */
        fSineWave = 1;
        f1KToneOn =1;
        f2KToneOn =0;
        set_dma0_ch0_stop();
        set_dma0_ch1_stop();
        set_dma0_ch0_i2s0_Lout();
        set_dma0_ch1_i2s0_Rout();
    }
    else if (Count_RTC < 20)
    {
        if(f2KToneOn ==1)
            return;
            
        /* 2KHz sine wave */
        fSineWave = 0;
        f1KToneOn =0;
        f2KToneOn =1;
        set_dma0_ch0_stop();
        set_dma0_ch1_stop();
        set_dma0_ch0_i2s0_Lout();
        set_dma0_ch1_i2s0_Rout();
    }
    else
    {
        Count_RTC =0;
        f1KToneOn =0;
        f2KToneOn =1;
    }
}
