//////////////////////////////////////////////////////////////////////////////
// * File name: timer.c
// *                                                                          
// * Description:  Timer functions.
// *                                                                          
// * Copyright (C) 2010 Texas Instruments Incorporated - http://www.ti.com/ 
// * Copyright (C) 2010 Spectrum Digital, Incorporated
// *                                                                          
// *                                                                          
// *  Redistribution and use in source and binary forms, with or without      
// *  modification, are permitted provided that the following conditions      
// *  are met:                                                                
// *                                                                          
// *    Redistributions of source code must retain the above copyright        
// *    notice, this list of conditions and the following disclaimer.         
// *                                                                          
// *    Redistributions in binary form must reproduce the above copyright     
// *    notice, this list of conditions and the following disclaimer in the   
// *    documentation and/or other materials provided with the                
// *    distribution.                                                         
// *                                                                          
// *    Neither the name of Texas Instruments Incorporated nor the names of   
// *    its contributors may be used to endorse or promote products derived   
// *    from this software without specific prior written permission.         
// *                                                                          
// *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS     
// *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT       
// *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR   
// *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT    
// *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,   
// *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT        
// *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,   
// *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY   
// *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT     
// *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE   
// *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.    
// *                                                                          
//////////////////////////////////////////////////////////////////////////////

#include "csl_gpt.h"
#include "usbstk5505.h"

Uint16 fTimer =0;
CSL_Handle    hGpt;

/*
 *  Timer0Init( )
 *      Initialize timer 0
 */
void Timer0Init(void)
{
    CSL_Status    status;
    CSL_Config    hwConfig;
    CSL_GptObj    gptObj;
    
    /* Open the CSL GPT module */
    hGpt = GPT_open (GPT_0, &gptObj, &status);
    
    /* Reset the GPT module */
    status = GPT_reset(hGpt);
    
    /* Timer interval 0.5sec (2Hz)*/
    hwConfig.autoLoad    = GPT_AUTO_ENABLE;
    hwConfig.ctrlTim     = GPT_TIMER_ENABLE;
    hwConfig.preScaleDiv = GPT_PRE_SC_DIV_11;  // Pre scale Divide input clock by 4096
                                               // 98.304M/4096 = 24K 
    hwConfig.prdLow      = 0x2EE0;             // 24K/12K = 2Hz (12K = 0x2EE0)
    hwConfig.prdHigh     = 0x0000;
    
    /* Configure Timer0 */
    status =  GPT_config(hGpt, &hwConfig);
    
    /* Start timer */
    GPT_start(hGpt);    
}

/*
 *  Timer_isr( )
 *      Timer 0 interrupt service routine. This function is called
 *      whenever ther is a Timer interrupt.
 */
interrupt void Timer_isr(void)
{
    /* Clear timer int flag */
    CSL_CPU_REGS->IFR0 &= 0x0010; 
    
    /* Clear timer0 int flag */
    CSL_TIM_0_REGS->TIMINT = 0x0001;
        
    /*Clear Timer0 bit in Timer Aggregate register */
    CSL_SYSCTRL_REGS->TIAFR |= 0x0001 ; 
    fTimer=1;
}
