/*
 *  Copyright 2009 by Spectrum Digital Incorporated.
 *  All rights reserved. Property of Spectrum Digital Incorporated.
 */
// IWĩx[X́Ahmain_20200721_BeforeAddSynth_BUP.ch
//#############################################################################
// Orgel Resonater by T.Okutsu 20200407
//#############################################################################


#include "usbstk5505.h"
#include "usbstk5505_gpio.h"
#include "usbstk5505_i2c.h"
#include "stdio.h"
#include "register_system.h"//20140525 T.Okutsu for PLL_98MHz()


#define XmitL 0x10
#define XmitR 0x20


#define AIC3204_I2C_ADDR 0x18

#define IER0        *(volatile unsigned *)0x0000
#define IFR0        *(volatile unsigned *)0x0001
#define ST0_55      *(volatile unsigned *)0x0002
#define ST1_55      *(volatile unsigned *)0x0003
#define ST2_55      *(volatile unsigned *)0x004B
#define ST3_55      *(volatile unsigned *)0x0004
#define IER1        *(volatile unsigned *)0x0045
#define IFR1        *(volatile unsigned *)0x0046

//**************************************************************************
//        DMA0 Ch0 Register Addresses
//**************************************************************************
#define DMA0_CH0_SRC_LSW        *(ioport volatile unsigned *)0x0c00    // DMA0 Channel 0 Source LSW Address
#define DMA0_CH0_SRC_MSW        *(ioport volatile unsigned *)0x0c01    // DMA0 Channel 0 Source MSW Address
#define DMA0_CH0_DST_LSW        *(ioport volatile unsigned *)0x0c02    // DMA0 Channel 0 Destination LSW Address
#define DMA0_CH0_DST_MSW        *(ioport volatile unsigned *)0x0c03    // DMA0 Channel 0 Destination MSW Address
#define DMA0_CH0_TC_LSW         *(ioport volatile unsigned *)0x0c04    // DMA0 Channel 0 Length / Transfer Control LSW Register
#define DMA0_CH0_TC_MSW         *(ioport volatile unsigned *)0x0c05    // DMA0 Channel 0 Transfer Control MSW Register
//**************************************************************************
//        DMA0 Ch1 Register Addresses
//**************************************************************************
#define DMA0_CH1_SRC_LSW        *(ioport volatile unsigned *)0x0c20    // DMA0 Channel 1 Source LSW Address
#define DMA0_CH1_SRC_MSW        *(ioport volatile unsigned *)0x0c21    // DMA0 Channel 1 Source MSW Address
#define DMA0_CH1_DST_LSW        *(ioport volatile unsigned *)0x0c22    // DMA0 Channel 1 Destination LSW Address
#define DMA0_CH1_DST_MSW        *(ioport volatile unsigned *)0x0c23    // DMA0 Channel 1 Destination MSW Address
#define DMA0_CH1_TC_LSW         *(ioport volatile unsigned *)0x0c24    // DMA0 Channel 1 Length / Transfer Control LSW Register
#define DMA0_CH1_TC_MSW         *(ioport volatile unsigned *)0x0c25    // DMA0 Channel 1 Transfer Control MSW Register
//**************************************************************************
//        DMA0 Ch2 Register Addresses
//**************************************************************************
#define DMA0_CH2_SRC_LSW        *(ioport volatile unsigned *)0x0c40    // DMA0 Channel 2 Source LSW Address
#define DMA0_CH2_SRC_MSW        *(ioport volatile unsigned *)0x0c41    // DMA0 Channel 2 Source MSW Address
#define DMA0_CH2_DST_LSW        *(ioport volatile unsigned *)0x0c42    // DMA0 Channel 2 Destination LSW Address
#define DMA0_CH2_DST_MSW        *(ioport volatile unsigned *)0x0c43    // DMA0 Channel 2 Destination MSW Address
#define DMA0_CH2_TC_LSW         *(ioport volatile unsigned *)0x0c44    // DMA0 Channel 2 Length / Transfer Control LSW Register
#define DMA0_CH2_TC_MSW         *(ioport volatile unsigned *)0x0c45    // DMA0 Channel 2 Transfer Control MSW Register

//**************************************************************************
//        DMA0 Ch3 Register Addresses
//**************************************************************************
#define DMA0_CH3_SRC_LSW        *(ioport volatile unsigned *)0x0c60    // DMA0 Channel 3 Source LSW Address
#define DMA0_CH3_SRC_MSW        *(ioport volatile unsigned *)0x0c61    // DMA0 Channel 3 Source MSW Address
#define DMA0_CH3_DST_LSW        *(ioport volatile unsigned *)0x0c62    // DMA0 Channel 3 Destination LSW Address
#define DMA0_CH3_DST_MSW        *(ioport volatile unsigned *)0x0c63    // DMA0 Channel 3 Destination MSW Address
#define DMA0_CH3_TC_LSW         *(ioport volatile unsigned *)0x0c64    // DMA0 Channel 3 Length / Transfer Control LSW Register
#define DMA0_CH3_TC_MSW         *(ioport volatile unsigned *)0x0c65    // DMA0 Channel 3 Transfer Control MSW Register

//****************************************************************************************
//****************************************************************************************
//   DMA Event Source Registers
//****************************************************************************************
#define DMA0_CH10_EVENT_SRC     *(ioport volatile unsigned *)0x1C1A
#define DMA0_CH32_EVENT_SRC     *(ioport volatile unsigned *)0x1C1B
#define DMA1_CH10_EVENT_SRC     *(ioport volatile unsigned *)0x1C1C     // DMA1 channel 0 and channel 1 Event Source Register
#define DMA1_CH32_EVENT_SRC     *(ioport volatile unsigned *)0x1C1D     // DMA1 channel 3 and channel 2 Event Source Register
#define DMA2_CH10_EVENT_SRC     *(ioport volatile unsigned *)0x1C36     // DMA2 channel 0 and channel 1 Event Source Register
#define DMA2_CH32_EVENT_SRC     *(ioport volatile unsigned *)0x1C37     // DMA2 channel 3 and channel 2 Event Source Register
#define DMA3_CH10_EVENT_SRC     *(ioport volatile unsigned *)0x1C38     // DMA3 channel 0 and channel 1 Event Source Register
#define DMA3_CH32_EVENT_SRC     *(ioport volatile unsigned *)0x1C39     // DMA3 channel 3 and channel 2 Event Source Register


//****************************************************************************************
//         DMA 1
//**************************************************************************
//        DMA1 Ch0 Register Addresses
//**************************************************************************
#define DMA1_CH0_SRC_LSW        *(ioport volatile unsigned *)0x0D00    // DMA1 Channel 0 Source LSW Address
#define DMA1_CH0_SRC_MSW        *(ioport volatile unsigned *)0x0D01    // DMA1 Channel 0 Source MSW Address
#define DMA1_CH0_DST_LSW        *(ioport volatile unsigned *)0x0D02    // DMA1 Channel 0 Destination LSW Address
#define DMA1_CH0_DST_MSW        *(ioport volatile unsigned *)0x0D03    // DMA1 Channel 0 Destination MSW Address
#define DMA1_CH0_TC_LSW         *(ioport volatile unsigned *)0x0D04    // DMA1 Channel 0 Length / Transfer Control LSW Register
#define DMA1_CH0_TC_MSW         *(ioport volatile unsigned *)0x0D05    // DMA1 Channel 0 Transfer Control MSW Register

//**************************************************************************
//        DMA1 Ch1 Register Addresses
//**************************************************************************
#define DMA1_CH1_SRC_LSW        *(ioport volatile unsigned *)0x0D20    // DMA1 Channel 1 Source LSW Address
#define DMA1_CH1_SRC_MSW        *(ioport volatile unsigned *)0x0D21    // DMA1 Channel 1 Source MSW Address
#define DMA1_CH1_DST_LSW        *(ioport volatile unsigned *)0x0D22    // DMA1 Channel 1 Destination LSW Address
#define DMA1_CH1_DST_MSW        *(ioport volatile unsigned *)0x0D23    // DMA1 Channel 1 Destination MSW Address
#define DMA1_CH1_TC_LSW         *(ioport volatile unsigned *)0x0D24    // DMA1 Channel 1 Length / Transfer Control LSW Register
#define DMA1_CH1_TC_MSW         *(ioport volatile unsigned *)0x0D25    // DMA1 Channel 1 Transfer Control MSW Register

//**************************************************************************
//        DMA1 Ch2 Register Addresses
//**************************************************************************
#define DMA1_CH2_SRC_LSW        *(ioport volatile unsigned *)0x0D40    // DMA1 Channel 2 Source LSW Address
#define DMA1_CH2_SRC_MSW        *(ioport volatile unsigned *)0x0D41    // DMA1 Channel 2 Source MSW Address
#define DMA1_CH2_DST_LSW        *(ioport volatile unsigned *)0x0D42    // DMA1 Channel 2 Destination LSW Address
#define DMA1_CH2_DST_MSW        *(ioport volatile unsigned *)0x0D43    // DMA1 Channel 2 Destination MSW Address
#define DMA1_CH2_TC_LSW         *(ioport volatile unsigned *)0x0D44    // DMA1 Destination Address
#define DMA1_CH2_TC_MSW         *(ioport volatile unsigned *)0x0D45    // DMA1 Channel 2 Transfer Control MSW Register

//**************************************************************************
//        DMA1 Ch3 Register Addresses
//**************************************************************************
#define DMA1_CH3_SRC_LSW        *(ioport volatile unsigned *)0x0D60    // DMA1 Channel 3 Source LSW Address
#define DMA1_CH3_SRC_MSW        *(ioport volatile unsigned *)0x0D61    // DMA1 Channel 3 Source MSW Address
#define DMA1_CH3_DST_LSW        *(ioport volatile unsigned *)0x0D62    // DMA1 Channel 3 Destination LSW Address
#define DMA1_CH3_DST_MSW        *(ioport volatile unsigned *)0x0D63    // DMA1 Channel 3 Destination MSW Address
#define DMA1_CH3_TC_LSW         *(ioport volatile unsigned *)0x0D64    // DMA1 Destination Address
#define DMA1_CH3_TC_MSW         *(ioport volatile unsigned *)0x0D65    // DMA1 Channel 0 Transfer Control MSW Register


//****************************************************************************************
//   DMA Interrupt
//****************************************************************************************
#define DMA_IFR     *(ioport volatile unsigned *)0x1C30    // DMA Interrupt Flag Register
#define DMA_MSK     *(ioport volatile unsigned *)0x1C31    // DMA Interrupt Mask Flag Register

// DMA_IFR             Address:  0x1C30 (IO space)       DMA Interrupt Flag Register
// +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+
// |15:14:13:12|11:10: 9: 8| 7: 6: 5: 4| 3: 2: 1: 0|  <<== Bit Position
// +--+--+--+--+--+--+--+--+--+--+--+--+--+--:--:--+
// |rw:rw:rw:rw|rw:rw:rw:rw|rw:rw:rw:rw|rw:rw:rw:rw|  <<== Read / Write Access
// +--+--+--+--+--+--+--+--+--+--+--+--+--+--:--:--+
// | 0: 0: 0: 0| 0: 0: 0: 0| 0: 0: 0: 0| 0: 0: 0: 0|  <<== Reset Values
// +--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+--+
//   |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |   (Writing a '1' clears the bit; writing a '0' has no effect)
//   |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  +-- [0]  DMA0_CH0_INTF (0=no interrupt occured, 1=interrupt occured)
//   |  |  |  |  |  |  |  |  |  |  |  |  |  |  +----- [1]  DMA0_CH1_INTF (0=no interrupt occured, 1=interrupt occured)
//   |  |  |  |  |  |  |  |  |  |  |  |  |  +-------- [2]  DMA0_CH2_INTF (0=no interrupt occured, 1=interrupt occured)
//   |  |  |  |  |  |  |  |  |  |  |  |  +----------- [3]  DMA0_CH3_INTF (0=no interrupt occured, 1=interrupt occured)
//   |  |  |  |  |  |  |  |  |  |  |  |
//   |  |  |  |  |  |  |  |  |  |  |  +-------------- [4]  DMA1_CH0_INTF (0=no interrupt occured, 1=interrupt occured)
//   |  |  |  |  |  |  |  |  |  |  +----------------- [5]  DMA1_CH1_INTF (0=no interrupt occured, 1=interrupt occured)
//   |  |  |  |  |  |  |  |  |  +-------------------- [6]  DMA1_CH2_INTF (0=no interrupt occured, 1=interrupt occured)
//   |  |  |  |  |  |  |  |  +----------------------- [7]  DMA1_CH3_INTF (0=no interrupt occured, 1=interrupt occured)
//   |  |  |  |  |  |  |  |
//   |  |  |  |  |  |  |  +-------------------------- [8]  DMA2_CH0_INTF (0=no interrupt occured, 1=interrupt occured)
//   |  |  |  |  |  |  +----------------------------- [9]  DMA2_CH1_INTF (0=no interrupt occured, 1=interrupt occured)
//   |  |  |  |  |  +-------------------------------- [10] DMA2_CH2_INTF (0=no interrupt occured, 1=interrupt occured)
//   |  |  |  |  +----------------------------------- [11] DMA2_CH3_INTF (0=no interrupt occured, 1=interrupt occured)
//   |  |  |  |
//   |  |  |  +-------------------------------------- [12] DMA3_CH0_INTF (0=no interrupt occured, 1=interrupt occured)
//   |  |  +----------------------------------------- [13] DMA3_CH1_INTF (0=no interrupt occured, 1=interrupt occured)
//   |  +-------------------------------------------- [14] DMA3_CH2_INTF (0=no interrupt occured, 1=interrupt occured)
//   +----------------------------------------------- [15] DMA3_CH3_INTF (0=no interrupt occured, 1=interrupt occured)




//extern cregister volatile unsigned int IER0;

//****************************************************************************

//20240925_TAC5112 Test	#define PLL_100M 1 //20200429
//20241128	#define PLL_98M 1 //fs=48kHz
	#define PLL_65M 1 //fs=8kHz 20241120


#define XMIT_BUFF_SIZE 48//20200317

#define XMIT_L_BUFF_SIZE	48
#define XMIT_R_BUFF_SIZE	48


//20200317 Appended follows
#define longUPPERLIMIT 1073741823 //vZKvȂ̂ŁA32bit{MAX(2147483647)̔
#define longBOTTOMLIMIT -1073741824 //vZKvȂ̂ŁA32bit[MAX(-2147483648)̔

#define shortUPPERLIMIT 32767 //16bit{MAX(65535)̔
#define shortBOTTOMLIMIT -32768 //16bit[MAX(-65536)̔

/*20200319*/ //TAC5112_2024
// -3dB 1 KHz sine sampled at 48 KHz
Int16 XmitL_Sine_1K[XMIT_L_BUFF_SIZE] = {
0x0000,0x0B6C,0x16A6,0x217C,0x2BC0,0x3544,0x3DDF,0x456B, 
0x4BC7,0x50D7,0x5485,0x56C0,0x5780,0x56C0,0x5485,0x50D7, 
0x4BC7,0x456B,0x3DDF,0x3544,0x2BC0,0x217C,0x16A6,0x0B6C, 
0x0000,0xF494,0xE95A,0xDE84,0xD440,0xCABC,0xC221,0xBA95, 
0xB439,0xAF29,0xAB7B,0xA940,0xA880,0xA940,0xAB7B,0xAF29, 
0xB439,0xBA95,0xC221,0xCABC,0xD440,0xDE84,0xE95A,0xF494
};

// -3dB 1 KHz sine sampled at 48 KHz
Int16 XmitR_Sine_1K[XMIT_R_BUFF_SIZE] = {
0x0000,0x0B6C,0x16A6,0x217C,0x2BC0,0x3544,0x3DDF,0x456B, 
0x4BC7,0x50D7,0x5485,0x56C0,0x5780,0x56C0,0x5485,0x50D7, 
0x4BC7,0x456B,0x3DDF,0x3544,0x2BC0,0x217C,0x16A6,0x0B6C, 
0x0000,0xF494,0xE95A,0xDE84,0xD440,0xCABC,0xC221,0xBA95, 
0xB439,0xAF29,0xAB7B,0xA940,0xA880,0xA940,0xAB7B,0xAF29, 
0xB439,0xBA95,0xC221,0xCABC,0xD440,0xDE84,0xE95A,0xF494
};

//-3 dB 2 KHz sine sampled at 48 KHz
Int16 XmitR_Sine_2K[XMIT_R_BUFF_SIZE] = {
0x0000,0x16A6,0x2BC0,0x3DDF,0x4BC7,0x5485,0x5780,0x5485, 
0x4BC7,0x3DDF,0x2BC0,0x16A6,0x0000,0xE95A,0xD440,0xC221, 
0xB439,0xAB7B,0xA880,0xAB7B,0xB439,0xC221,0xD440,0xE95A,
0x0000,0x16A6,0x2BC0,0x3DDF,0x4BC7,0x5485,0x5780,0x5485, 
0x4BC7,0x3DDF,0x2BC0,0x16A6,0x0000,0xE95A,0xD440,0xC221, 
0xB439,0xAB7B,0xA880,0xAB7B,0xB439,0xC221,0xD440,0xE95A
};

// -3dB 1 KHz sine sampled at 8 KHz
Int16 XmitR_Sine_1Kat8KHz[XMIT_L_BUFF_SIZE] = {
0x0000,0x3DDF,0x5780,0x3DDF,0x0000,0xC221,0xA880,0xC221,
0x0000,0x3DDF,0x5780,0x3DDF,0x0000,0xC221,0xA880,0xC221,
0x0000,0x3DDF,0x5780,0x3DDF,0x0000,0xC221,0xA880,0xC221,
0x0000,0x3DDF,0x5780,0x3DDF,0x0000,0xC221,0xA880,0xC221,
0x0000,0x3DDF,0x5780,0x3DDF,0x0000,0xC221,0xA880,0xC221,
0x0000,0x3DDF,0x5780,0x3DDF,0x0000,0xC221,0xA880,0xC221
};

// -3dB 2 KHz sine sampled at 8 KHz
Int16 XmitR_Sine_2Kat8KHz[XMIT_L_BUFF_SIZE] = {
0x0000,0x5780,0x0000,0xA880,0x0000,0x5780,0x0000,0xA880,
0x0000,0x5780,0x0000,0xA880,0x0000,0x5780,0x0000,0xA880,
0x0000,0x5780,0x0000,0xA880,0x0000,0x5780,0x0000,0xA880,
0x0000,0x5780,0x0000,0xA880,0x0000,0x5780,0x0000,0xA880,
0x0000,0x5780,0x0000,0xA880,0x0000,0x5780,0x0000,0xA880,
0x0000,0x5780,0x0000,0xA880,0x0000,0x5780,0x0000,0xA880
};

// 0dB 1 KHz sine sampled at 48 KHz
    Int16 FS_sinetbl[48] = {
        0x0000, 0x10b4, 0x2120, 0x30fb, 0x3fff, 0x4dea, 0x5a81, 0x658b,
        0x6ed8, 0x763f, 0x7ba1, 0x7ee5, 0x7ffd, 0x7ee5, 0x7ba1, 0x76ef,
        0x6ed8, 0x658b, 0x5a81, 0x4dea, 0x3fff, 0x30fb, 0x2120, 0x10b4,
        0x0000, 0xef4c, 0xdee0, 0xcf06, 0xc002, 0xb216, 0xa57f, 0x9a75,
        0x9128, 0x89c1, 0x845f, 0x811b, 0x8002, 0x811b, 0x845f, 0x89c1,
        0x9128, 0x9a76, 0xa57f, 0xb216, 0xc002, 0xcf06, 0xdee0, 0xef4c
    };

/*20200319*/ //TAC5112_2024

//20190412
Int16 RcvL1[XMIT_BUFF_SIZE];
Int16 RcvR1[XMIT_BUFF_SIZE];
Int16 RcvL2[XMIT_BUFF_SIZE];
Int16 RcvR2[XMIT_BUFF_SIZE];

//Int16 XmitL1[XMIT_BUFF_SIZE];
//Int16 XmitR1[XMIT_BUFF_SIZE];
//Int16 XmitL2[XMIT_BUFF_SIZE];
//Int16 XmitR2[XMIT_BUFF_SIZE];

Int16 TrsL1[XMIT_BUFF_SIZE];
Int16 TrsR1[XMIT_BUFF_SIZE];
Int16 TrsL2[XMIT_BUFF_SIZE];
Int16 TrsR2[XMIT_BUFF_SIZE];

Int16 AnotherChBuff_1[XMIT_BUFF_SIZE];//20200323
Int16 AnotherChBuff_2[XMIT_BUFF_SIZE];//20200323

Int16 TrsLchBuff_1[XMIT_BUFF_SIZE];
Int16 TrsLchBuff_2[XMIT_BUFF_SIZE];
Int16 TrsRchBuff_1[XMIT_BUFF_SIZE];
Int16 TrsRchBuff_2[XMIT_BUFF_SIZE];



Uint32 RxL1_DMA_address;
Uint32 RxL2_DMA_address;
Uint32 RxR1_DMA_address;
Uint32 RxR2_DMA_address;
Uint32 TxL1_DMA_address;
Uint32 TxL2_DMA_address;
Uint32 TxR1_DMA_address;
Uint32 TxR2_DMA_address;

volatile Uint16 CurrentRxL_DMAChannel;
volatile Uint16 CurrentRxR_DMAChannel;
volatile Uint16 CurrentTxL_DMAChannel;
volatile Uint16 CurrentTxR_DMAChannel;

volatile Uint16 InputOperatingForL;
volatile Uint16 InputOperatingForR;
volatile Uint16 OutputOperatingForL;
volatile Uint16 OutputOperatingForR;

short gMix_L, gMix_R;//̪Ċ֐ƂL/Rւ̍ŏIo

interrupt void DMA_Isr(void);

void buff_copy(Int16 *input, Int16 *output, Int16 size);
void EchoFx(short Src);


#define TAC5112_I2C_ADDR	0x50 //20240918
Uint8 code_TAC5112; //20240918
//20240924 Uint8* cmd; //20240918

#define AIC3109_I2C_ADDR	0x18 //20241019
Uint8 code_AIC3109; //20241019
Uint8 code_AIC3204; //20241123
Uint16* codeADRS_AIC3109; //20241122
Uint8* codeADRS_AIC3204; //20241123


//****************************************************************************
void PLL_98MHz(void)
{
// PLL set up from RTC
    // bypass PLL
    CONFIG_MSW = 0x0;

#if (PLL_100M ==1)
    PLL_CNTL2 = 0x8000;
    PLL_CNTL4 = 0x0000;
    PLL_CNTL3 = 0x0806;
//20210412test    PLL_CNTL1 = 0x8BE8; //PG1.4: 0x82FA;
	PLL_CNTL1 = 0x82E8; //PG1.4: 0x82FA;
//20210412test	PLL_CNTL1 = 0x8174; //PG1.4: 0x82FA;
    
#elif (PLL_12M ==1)
    PLL_CNTL2 = 0x8000;//RD=0
    PLL_CNTL4 = 0x0200;
    PLL_CNTL3 = 0x0806;
    PLL_CNTL1 = 0x82ED;
#elif (PLL_65M ==1)    
	PLL_CNTL2 = 0x8000;
    PLL_CNTL4 = 0x0000;
    PLL_CNTL3 = 0x0806;
//20241111	PLL_CNTL1 = 0x82ED;//PLL=12.288MHz CLKREF(32.768kHz) x 3000(=749x4+4)/4/2 See Page-42/94 of SPRUFP0 Document.
//20240925_TAC5112 Test	PLL_CNTL1 = 0x807C;//20240925 PLL=2.048MHz CLKREF(32.768kHz) x 500(=124x4+4)/4/2 See Page-42/94 of SPRUFP0 Document.
//20241111	PLL_CNTL1 = 0x87CF;//PLL=65.536MHz CLKREF(32.768kHz) x 8000(=1999x4+4)/4/2 See Page-42/94 of SPRUFP0 Document.

//[for setting to fs=8kHz]
	PLL_CNTL1 = 0x81F3;//PLL=65.536MHz CLKREF(32.768kHz) x 2000(=499x4+4) See Page-42/94 of SPRUFP0 Document.

#elif (PLL_98M ==1)    
	PLL_CNTL2 = 0x8000;
    PLL_CNTL4 = 0x0000;
    PLL_CNTL3 = 0x0806;

	PLL_CNTL1 = 0x82ED;//PLL=98.304MHz CLKREF(32.768kHz) x 3000(=749x4+4) See Page-42/94 of SPRUFP0 Document.
    
#endif
    while ( (PLL_CNTL3 & 0x0008) == 0);
    // Switch to PLL clk
    CONFIG_MSW = 0x1;//SYSCLKSEL=1
}

//****************************************************************************
void InitSystem(void)
{
	Uint16 i;
// PLL set up from RTC
    // bypass PLL
    CONFIG_MSW = 0x0;

#if (PLL_100M ==1)
    PLL_CNTL2 = 0x8000;
    PLL_CNTL4 = 0x0000;
    PLL_CNTL3 = 0x0806;
    PLL_CNTL1 = 0x8BE8; //PG1.4: 0x82FA;
    
#elif (PLL_12M ==1)
    PLL_CNTL2 = 0x8000;
    PLL_CNTL4 = 0x0200;
    PLL_CNTL3 = 0x0806;
    PLL_CNTL1 = 0x82ED;
#elif (PLL_98M ==1)    
    PLL_CNTL2 = 0x8000;
    PLL_CNTL4 = 0x0000;
    PLL_CNTL3 = 0x0806;
    PLL_CNTL1 = 0x82ED;

#elif (PLL_40M ==1)        
    PLL_CNTL2 = 0x8000;
    PLL_CNTL4 = 0x0300;
    PLL_CNTL3 = 0x0806;
    PLL_CNTL1 = 0x8262;    
#endif

    while ( (PLL_CNTL3 & 0x0008) == 0);
    // Switch to PLL clk
    CONFIG_MSW = 0x1;

// clock gating
// enable all clocks
    IDLE_PCGCR = 0x0;
    IDLE_PCGCR_MSW = 0xFF84;
    

// reset peripherals
    PER_RSTCOUNT = 0x02;
    PER_RESET = 0x00fb;    
    for (i=0; i< 0xFFF; i++);
}

//****************************************************************************
void ConfigPort(void)
{
    Int16 i;
    //  configure ports
    PERIPHSEL0 = 0x6900;        // parallel port: mode 6, serial port1: mode 2 

//20200417    for (i=0; i< 0xFFF; i++);
    for (i=0; i< 0xFFFF; i++);
}

//****************************************************************************
void SYS_GlobalIntEnable(void)
{
    asm(" BIT (ST1, #ST1_INTM) = #0");
}
//****************************************************************************
void SYS_GlobalIntDisable(void)
{
    asm(" BIT (ST1, #ST1_INTM) = #1");
}

//****************************************************************************
//Int16 AIC3204_rget(  Uint16 regnum, Uint16* regval )
//20241123	Int16 AIC3204_rget(  Uint16 regnum, Uint8* regval )
Int8 AIC3204_rget(  Uint16 regnum )
{
    Int16  retcode = 0;
//20240925_TAC5112 Test    Uint16 cmd[2];
Uint8 cmd[2];//20240925_TAC5112 Test

//20240925_TAC5112 Test    cmd[0] = regnum & 0x007F;       // 7-bit Device Register
    cmd[0] = (Uint8)(regnum & 0x007F);       // 7-bit Device Register
    cmd[1] = 0;

    retcode |= USBSTK5505_I2C_write( (Uint16)AIC3204_I2C_ADDR, (Uint8*)cmd, 1 );
    retcode |= USBSTK5505_I2C_read( (Uint16)AIC3204_I2C_ADDR, (Uint8*)cmd, 1 );

//20241123    *regval = cmd[0];
    USBSTK5505_wait( 10 );
//20241123    return retcode;
    return cmd[0];//20241123
}
//****************************************************************************
//Int16 TAC5112_rget(  Uint16 regnum, Uint16* regval )
//Int16 TAC5112_rget(  Uint16 regnum, Uint8* regval )
Int8 TAC5112_rget(  Uint16 regnum )
{
    Int16  retcode = 0;
//20240925_TAC5112 Test    Uint16 cmd[2];
Uint8 cmd[2];//20240925_TAC5112 Test

//20240925_TAC5112 Test    cmd[0] = regnum & 0x007F;       // 7-bit Device Register
    cmd[0] = (Uint8)(regnum & 0x007F);       // 7-bit Device Register
    cmd[1] = 0;

    retcode |= USBSTK5505_I2C_write( (Uint16)TAC5112_I2C_ADDR, (Uint8*)cmd, 1 );
    retcode |= USBSTK5505_I2C_read( (Uint16)TAC5112_I2C_ADDR, (Uint8*)cmd, 1 );

//20240925_TAC5112 Test    *regval = cmd[0];
    USBSTK5505_wait( 10 );
    //20240925_TAC5112 Test return retcode;
    return cmd[0];//20240925_TAC5112 Test
}
//****************************************************************************
Int8 AIC3109_rget(  Uint8 regnum )
//20241122 Int8 AIC3109_rget(  Uint8 regnum, Uint16* regval )

{
    Int16  retcode = 0;
Uint8 cmd[2];

    cmd[0] = (Uint8)(regnum & 0x007F);       // 7-bit Device Register
    cmd[1] = 0;

//20241122    retcode |= USBSTK5505_I2C_write( (Uint16)AIC3109_I2C_ADDR, (Uint8*)cmd, 1 );
    retcode |= USBSTK5505_I2C_write_NS( (Uint16)AIC3109_I2C_ADDR, (Uint8*)cmd, 1 );//20241122
    retcode |= USBSTK5505_I2C_read( (Uint16)AIC3109_I2C_ADDR, (Uint8*)cmd, 1 );

    USBSTK5505_wait( 100 );
    return cmd[0];
}
//****************************************************************************
Int16 AIC3204_rset( Uint16 regnum, Uint16 regval )
{
	unsigned char cmd[2];
	cmd[0] = regnum & 0x007F;	// 7-bit Device Address
	cmd[1] = regval;			// 8-bit Register Data
	
    USBSTK5505_waitusec( 300 );
	
	return USBSTK5505_I2C_write( AIC3204_I2C_ADDR, cmd, 2 );//eZDsp5535̏ꍇABSL EZDSP5535_I2C_write( AIC3204_I2C_ADDR, cmd, 2 )B
}
//****************************************************************************
Int16 TAC5112_rset( Uint16 regnum, Uint16 regval )
{
	unsigned char cmd[2];
	cmd[0] = regnum & 0x007F;	// 7-bit Device Address
	cmd[1] = regval;			// 8-bit Register Data
	
    USBSTK5505_waitusec( 300 );
	
	return USBSTK5505_I2C_write( TAC5112_I2C_ADDR, cmd, 2 );//eZDsp5535̏ꍇABSL EZDSP5535_I2C_write( AIC3204_I2C_ADDR, cmd, 2 )B
}
//****************************************************************************
Int16 AIC3109_rset( Uint8 regnum, Uint8 regval )
{
	unsigned char cmd[2];
//20241021	cmd[0] = regnum & 0x007F;	// 7-bit Device Address
//20241021	cmd[1] = regval;			// 8-bit Register Data
//20241021	a = cmd[0] = (Uint8)regnum & 0x007F;	// 7-bit Device Address
	cmd[0] = (Uint8)regnum & 0x7F;	// 7-bit Device Address
	cmd[1] = (Uint8)regval;			// 8-bit Register Data
	
    USBSTK5505_waitusec( 300 );
	
	return USBSTK5505_I2C_write( AIC3109_I2C_ADDR, cmd, 2 );//eZDsp5535̏ꍇABSL EZDSP5535_I2C_write( AIC3204_I2C_ADDR, cmd, 2 )B
//20241021	return USBSTK5505_I2C_write( (Uint16)AIC3109_I2C_ADDR, cmd, (Uint16)2 );//eZDsp5535̏ꍇABSL EZDSP5535_I2C_write( AIC3204_I2C_ADDR, cmd, 2 )B
}
//****************************************************************************
void AIC3204_Init(void)
{
	SYS_EXBUSSEL |= 0x0020;		// Select A20/GPIO26 as GPIO26
	USBSTK5505_GPIO_init();
	USBSTK5505_GPIO_setDirection(GPIO26, GPIO_OUT);
	USBSTK5505_GPIO_setOutput( GPIO26, 1 );		// Take AIC3201 chip out of reset
	USBSTK5505_I2C_init( );						// Initialize I2C, eZDsp5535̏ꍇBSL̒EZDSP5535_I2C_init( )B

	/* Configure Serial Bus */
//TAC5112_20240803	SYS_EXBUSSEL |= 0x0100;		// Configure Serial bus 0 for I2S0
SYS_EXBUSSEL |= 0x0400;	//TAC5112_20240803	// Configure Serial bus 0 for I2S2

	/* Configure AIC3204 */

/*TAC5112_20241004
	AIC3204_rset( 0, 0 );		// Select page 1
	AIC3204_rset( 1, 1 );		// Reset codec
	AIC3204_rset( 0, 1 );		// Point to page 1
	AIC3204_rset( 1, 8 );		// Disable crude AVDD generation from DVDD
	AIC3204_rset( 2, 1 );		// Enable Analog Blocks, use LDO power
	AIC3204_rset( 0, 0 );
	// PLL and Clocks config and Power Up
	AIC3204_rset( 27, 0x0d );	// BCLK and WCLK is set as o/p to AIC3204(Master)
	AIC3204_rset( 28, 0x00 );	// Data ofset = 0
	AIC3204_rset( 4, 3 );		// PLL setting: PLLCLK <- MCLK, CODEC_CLKIN <-PLL CLK
	AIC3204_rset( 6, 8 );		// PLL setting: J=8
	AIC3204_rset( 7, 15 );		// PLL setting: HI_BYTE(D)
	AIC3204_rset( 8, 0xdc ); 	// PLL setting: LO_BYTE(D)
	AIC3204_rset( 30, 0x88 );	// For 32 bit clocks per frame in Master mode ONLY
								// BCLK=DAC_CLK/N =(12288000/8) = 1.536MHz = 32*fs
//20210412test	AIC3204_rset( 30, 0x90 );	// For 32 bit clocks per frame in Master mode ONLY
//20210412test								// BCLK=DAC_CLK/N =(12288000/16(0x10=.0x90)) = 768kHz = 32*fs
//20210412test	AIC3204_rset( 30, 0x98 );	// For 32 bit clocks per frame in Master mode ONLY
//20210412test								// BCLK=DAC_CLK/N =(12288000/24(0x18=.0x98)) = 576kHz = 32*fs
	AIC3204_rset( 5, 0x91 );	//?;PLL setting: Power up PLL, P=1 and R=1
	AIC3204_rset( 13, 0 );		// Hi_Byte(DOSR) for DOSR = 128 decimal or 0x0080 DAC oversamppling
	AIC3204_rset( 14, 0x80 );	// Lo_Byte(DOSR) for DOSR = 128 decimal or 0x0080
	AIC3204_rset( 20, 0x80 );	// AOSR for AOSR = 128 decimal or 0x0080 for decimation filters 1 to 6
	AIC3204_rset( 11, 0x88 );	// Power up NDAC and set NDAC value to 8
	AIC3204_rset( 12, 0x82 );	// Power up MDAC and set MDAC value to 2
	AIC3204_rset( 18, 0x88 );	// Power up NADC and set NADC value to 8
	AIC3204_rset( 19, 0x82 );	// Power up MADC and set MADC value to 2
	// DAC ROUTING and Power Up
	AIC3204_rset( 0, 1 );		// Select page 1
	AIC3204_rset( 0x0c, 8 );	// LDAC AFIR routed to HPL
	AIC3204_rset( 0x0d, 8 );	// RDAC AFIR routed to HPR
	AIC3204_rset( 0, 0 );		// Select page 0
	AIC3204_rset( 64, 2 );		// Left vol=right vol
	AIC3204_rset( 65, 0);		// Left DAC gain to 0dB VOL; Right tracks Left
	AIC3204_rset( 63, 0xd4 );	// Power up left,right data paths and set channel
	AIC3204_rset( 0, 1 );		// Select page 1
	AIC3204_rset( 0x10, 0x3a );	// Unmute HPL , -6dB gain
	AIC3204_rset( 0x11, 0x3a );	// Unmute HPR , -6dB gain
	AIC3204_rset( 9, 0x30 );	// Power up HPL,HPR
	AIC3204_rset( 0, 0 );		// Select page 0
	USBSTK5505_wait( 100 );	// waitAeZDsp5535̏ꍇ́ABSL EZDSP5535_waitusec( 300 )ȂǂB
	// ADC ROUTING and Power Up
	AIC3204_rset( 0, 1 );		// Select page 1
	AIC3204_rset( 0x34, 0x30 );	// STEREO 1 Jack
								// IN2_L to LADC_P through 40 kohm
	AIC3204_rset( 0x37, 0x30 );	// IN2_R to RADC_P through 40 kohmm
	AIC3204_rset( 0x36, 3 );	// CM_1 (common mode) to LADC_M through 40 kohm
	AIC3204_rset( 0x39, 0xc0 );	// CM_1 (common mode) to RADC_M through 40 kohm

//20200509	AIC3204_rset( 0x3b, 0 );	// MIC_PGA_L unmute(for Line_Level)
//20200509	AIC3204_rset( 0x3c, 0 );	// MIC_PGA_R unmute(for Line_Level)
AIC3204_rset( 0x3b, 60 );	// MIC_PGA_L +30dB(for Mic_Level)
AIC3204_rset( 0x3c, 60 );	// MIC_PGA_R +30dB(for Mic_Level)
//20200410AIC3204_rset( 0x33, 0x40 );	// MICBIAS Powered Up BIAS = LDOIN

	AIC3204_rset( 0, 0 );		// Select page 0
	AIC3204_rset( 0x51, 0xc0 );	// Powerup Left and Right ADC
	AIC3204_rset( 0x52, 0 );	// Unmute Left and Right ADC
    
	AIC3204_rset( 0, 0 );
	USBSTK5505_wait( 200 );	// WaitAeZDsp5535̏ꍇ́ABSL EZDSP5535_waitusec( 300 )ȂǂB
TAC5112_20241004*/

}
//****************************************************************************
void CODEC_Init(void)
{
	SYS_EXBUSSEL |= 0x0020;		// Select A20/GPIO26 as GPIO26
	USBSTK5505_GPIO_init();
	USBSTK5505_GPIO_setDirection(GPIO26, GPIO_OUT);
	USBSTK5505_GPIO_setOutput( GPIO26, 1 );		// Take AIC3201 chip out of reset
	USBSTK5505_I2C_init( );						// Initialize I2C, eZDsp5535̏ꍇBSL̒EZDSP5535_I2C_init( )B

	/* Configure Serial Bus */
//TAC5112_20240803	SYS_EXBUSSEL |= 0x0100;		// Configure Serial bus 0 for I2S0
SYS_EXBUSSEL |= 0x0400;	//TAC5112_20240926	// Configure Serial bus 0 for I2S2

	// Configure TAC5112 as follows


	USBSTK5505_wait( 200 );	// WaitAeZDsp5535̏ꍇ́ABSL EZDSP5535_waitusec( 300 )ȂǂB

}
//################################################################################
void setDMA_address(void)
{
// double buffer with filtering    
	RxL1_DMA_address = (Uint32)RcvL1;   
	RxL1_DMA_address = (RxL1_DMA_address<<1) + 0x10000;		// change word address to byte address and add DARAM offset for DMA

	RxL2_DMA_address = (Uint32)RcvL2;   
	RxL2_DMA_address = (RxL2_DMA_address<<1) + 0x10000;		// change word address to byte address and add DARAM offset for DMA

	RxR1_DMA_address = (Uint32)RcvR1;   
	RxR1_DMA_address = (RxR1_DMA_address<<1) + 0x10000;		// change word address to byte address and add DARAM offset for DMA

	RxR2_DMA_address = (Uint32)RcvR2;   
	RxR2_DMA_address = (RxR2_DMA_address<<1) + 0x10000;		// change word address to byte address and add DARAM offset for DMA

	TxL1_DMA_address = (Uint32)TrsL1;   
	TxL1_DMA_address = (TxL1_DMA_address<<1) + 0x10000;		// change word address to byte address and add DARAM offset for DMA

	TxL2_DMA_address = (Uint32)TrsL2;   
	TxL2_DMA_address = (TxL2_DMA_address<<1) + 0x10000;		// change word address to byte address and add DARAM offset for DMA
    
	TxR1_DMA_address = (Uint32)TrsR1;   
	TxR1_DMA_address = (TxR1_DMA_address<<1) + 0x10000;		// change word address to byte address and add DARAM offset for DMA
    
	TxR2_DMA_address = (Uint32)TrsR2;   
	TxR2_DMA_address = (TxR2_DMA_address<<1) + 0x10000;		// change word address to byte address and add DARAM offset for DMA      
}
//****************************************************************************
void I2S_Start(void)
{
	/* I2S settings */

#if (PLL_98M ==1)

//TAC5112_20240803	I2S0_SRGR = 0x0;	//1/8fs, 1/2Clk_Divide, by SampleRate Generate Reg.
	I2S2_SRGR = 0x0015;	//FS=1.536MHz x 1/32(=48kHz), BCLK=98MHz x 1/64(=1.536MHz)Clk_Divide, by SampleRate Generate Reg.
	I2S2_CR = 0x8092;	//({͂)Enable I2S, 16-bit word "10b"(bit5`24h), master, DataPack,


#elif (PLL_65M ==1)
//%%% fsύX 
	I2S2_SRGR = 0x0017;	//FS=0.256MHz x 1/32(=8kHz), BCLK=65.536MHz x 1/256(=0.256MHz)Clk_Divide, by SampleRate Generate Reg.
//20241120_Test	I2S2_SRGR = 0x0016;	//FS=0.512MHz x 1/32(=16kHz), BCLK=65.536MHz x 1/128(=0.512MHz)Clk_Divide, by SampleRate Generate Reg.
//20241120_Test	I2S2_SRGR = 0x0015;	//FS=1.024MHz x 1/32(=32kHz), BCLK=65.536MHz x 1/64(=1.024MHz)Clk_Divide, by SampleRate Generate Reg.

//20200331test	I2S0_SRGR = 0x4;	//1/8fs, 1/8Clk_Divide, by SampleRate Generate Reg.
	//I2S0_CR = 0x8010;	// 16-bit word "10b"(bit5`24h), slave, enable I2C

//$$$$$$$$$$$$$$$$$$$ vӁIb΍ $$$$$$$$$$$$$$$$$$$$$$
//TAC5112_20240803	I2S0_CR = 0x8090;	//Enable I2S, 16-bit word "10b"(bit5`24h), slave, DataPack,
	I2S2_CR = 0x8092;	//Enable I2S, DataPack, 16-bit word "10b"(bit5`24h), master,

//20241203_Test	I2S2_CR = 0x8012;	//(ԈႢ)Enable I2S, 16-bit word "10b"(bit5`24h), master, NonDataPack,
//20241203_Test	I2S2_CR = 0x8512;	//Enable I2S, FSPOL->'1":Pulsed Low(Like DSP Mode), CLK_POL->'0':Rising_edge, DATA Delay->'1':2bit Delay, 16-bit word "10b"(bit5`24h), master,NonDataPack, NonSignExt, 
//20241203_Test	I2S2_CR = 0x80D2;	//Enable I2S, FSPOL->'1":Pulsed Low(Like DSP Mode), CLK_POL->'0':Rising_edge, DATA Delay->'1':2bit Delay, 16-bit word "10b"(bit5`24h), master,NonDataPack, NonSignExt, 
//$$$$$$$$$$$$$$$$$$$ vӁIb΍ $$$$$$$$$$$$$$$$$$$$$$


#endif

}
//****************************************************************************
void set_dma0_ch0_stop(void)
{
	Uint16 temp;
//  DMA stop
//TAC5112_20240926	temp = DMA0_CH0_TC_MSW;
temp = DMA1_CH0_TC_MSW;//TAC5112_20240803
	temp &= 0x7FFF;
//TAC5112_20240926	DMA0_CH0_TC_MSW = temp;    
DMA1_CH0_TC_MSW = temp;//TAC5112_20240926    
}
//****************************************************************************
void set_dma0_ch1_stop(void)
{
	Uint16 temp;
//  DMA stop
//TAC5112_20240926	temp = DMA0_CH1_TC_MSW;
temp = DMA1_CH1_TC_MSW;//TAC5112_20240926
	temp &= 0x7FFF;
//TAC5112_20240926	DMA0_CH1_TC_MSW = temp;    
DMA1_CH1_TC_MSW = temp;//TAC5112_20240926    
}
//################################################################################
void set_dma0_ch2_stop(void)
{
Uint16 temp;
//  DMA stop
//TAC5112_20240926	temp = DMA0_CH2_TC_MSW;
temp = DMA1_CH2_TC_MSW;//TAC5112_20240926
	temp &= 0x7FFF;
//TAC5112_20240926	DMA0_CH2_TC_MSW = temp;    
DMA1_CH2_TC_MSW = temp;//TAC5112_20240926    
}
//################################################################################
void set_dma0_ch3_stop(void)
{
Uint16 temp;
//  DMA stop
//TAC5112_20240926	temp = DMA0_CH3_TC_MSW;
temp = DMA1_CH3_TC_MSW;//TAC5112_20240926
	temp &= 0x7FFF;
//TAC5112_20240926	DMA0_CH3_TC_MSW = temp;    
DMA1_CH3_TC_MSW = temp;//TAC5112_20240926    
}
//****************************************************************************
Uint16 set_dma0_ch0_i2s0_Lout(void)
{
	Uint16 temp; 
	Uint32 add;//TAC5112_20240926 for Sine_1kHz Out

//TAC5112_20240926	DMA0_CH0_TC_LSW = XMIT_BUFF_SIZE * 2;
DMA1_CH0_TC_LSW = XMIT_BUFF_SIZE * 2;

//TAC5112_20240926	DMA0_CH0_TC_MSW = 0x2204;	//src incre, destination fix, sync, No auto  
DMA1_CH0_TC_MSW = 0x2204;	//TAC5112_20240926//src incre, destination fix, sync, No auto  
//  DMA0_CH0_TC_MSW = 0x3204;	//src incre, destination fix, sync, auto  
	            
//TAC5112_20240926	temp = DMA0_CH10_EVENT_SRC;
temp = DMA1_CH10_EVENT_SRC;//TAC5112_20240926
//TAC5112_20240926	DMA0_CH10_EVENT_SRC = temp | 0x0001;	// I2S0 transmit event
DMA1_CH10_EVENT_SRC = temp | 0x0001;//TAC5112_20240926	// I2S0 transmit event
    
/*20200317 //TAC5112_20240803
	add = (Uint32)XmitL_Sine_1K;        
	add = (add<<1) + 0x10000;	// change word address to byte address and add DARAM offset for DMA
   
//TAC5112_20240926	DMA0_CH0_SRC_LSW = (Uint16)add;
DMA1_CH0_SRC_LSW = (Uint16)add;//TAC5112_20240926
//TAC5112_20240926	DMA0_CH0_SRC_MSW = 0xFFFF & (add >> 16);
DMA1_CH0_SRC_MSW = 0xFFFF & (add >> 16);//TAC5112_20240926
20200317*/ //TAC5112_20240803
//20200317
//20241109//20241129	DMA0_CH0_SRC_LSW = (Uint16)TxL1_DMA_address;
//20241109//20241129	DMA0_CH0_SRC_MSW = 0xFFFF & (TxL1_DMA_address >> 16);
	DMA1_CH0_SRC_LSW = (Uint16)TxL1_DMA_address;
	DMA1_CH0_SRC_MSW = 0xFFFF & (TxL1_DMA_address >> 16);


    
//TAC5112_20240803	DMA0_CH0_DST_LSW = 0x2808;	// is20 transmit left data register lsw
//TAC5112_20240926	DMA0_CH0_DST_LSW = 0x2A08;	// i2s2 transmit left data register lsw
DMA1_CH0_DST_LSW = 0x2A08;//TAC5112_20240926	// i2s2 transmit left data register lsw
    
//  DMA starts   
//TAC5112_20240926	temp = DMA0_CH0_TC_MSW;
temp = DMA1_CH0_TC_MSW;//TAC5112_20240926
	temp |= 0x8000;
//TAC5112_20240926	DMA0_CH0_TC_MSW = temp;
DMA1_CH0_TC_MSW = temp;//TAC5112_20240926

	return 0;
}
//****************************************************************************
Uint16 set_dma0_ch1_i2s0_Rout(void)
{	
	Uint16 temp;
	Uint32 add;//TAC5112_20240803

//TAC5112_20240926	DMA0_CH1_TC_LSW = XMIT_BUFF_SIZE * 2;
DMA1_CH1_TC_LSW = XMIT_BUFF_SIZE * 2;//TAC5112_20240926

//TAC5112_20240926	DMA0_CH1_TC_MSW = 0x2204;	//src incre, destination fix, sync, No auto  
DMA1_CH1_TC_MSW = 0x2204;//TAC5112_20240926	//src incre, destination fix, sync, No auto  
//  DMA0_CH1_TC_MSW = 0x3204;	//src incre, destination fix, sync, auto  
	
//TAC5112_20240926	temp = DMA0_CH10_EVENT_SRC;
temp = DMA1_CH10_EVENT_SRC;//TAC5112_20240926
//TAC5112_20240926	DMA0_CH10_EVENT_SRC = temp | 0x0100;	// I2S0 transmit event
DMA1_CH10_EVENT_SRC = temp | 0x0100;//TAC5112_20240926	// I2S0 transmit event
	
/*20200317 //TAC5112_20240803
	//add = (Uint32)XmitR_Sine_1K;        
	add = (Uint32)XmitR_Sine_2K;        
	add = (add<<1) + 0x10000;	// change word address to byte address and add DARAM offset for DMA
    
//TAC5112_20240926	DMA0_CH1_SRC_LSW = (Uint16)add;
DMA1_CH1_SRC_LSW = (Uint16)add;//TAC5112_20240926
//TAC5112_20240926	DMA0_CH1_SRC_MSW = 0xFFFF & (add >> 16);
DMA1_CH1_SRC_MSW = 0xFFFF & (add >> 16);//TAC5112_20240926
20200317*/ //TAC5112_20240803
//20200317
//20241109//20241129	DMA0_CH1_SRC_LSW = (Uint16)TxR1_DMA_address;
//20241109//20241129	DMA0_CH1_SRC_MSW = 0xFFFF & (TxR1_DMA_address >> 16);
	DMA1_CH1_SRC_LSW = (Uint16)TxR1_DMA_address;
	DMA1_CH1_SRC_MSW = 0xFFFF & (TxR1_DMA_address >> 16);


//TAC5112_20240803	DMA0_CH1_DST_LSW = 0x280C;	// is20 transmit right data register lsw
//TAC5112_20240926	DMA0_CH1_DST_LSW = 0x2A0C;	// i2s2 transmit right data register lsw
DMA1_CH1_DST_LSW = 0x2A0C;//TAC5112_20240926	// i2s2 transmit right data register lsw

// DMA starts    
//TAC5112_20240926	temp = DMA0_CH1_TC_MSW;
temp = DMA1_CH1_TC_MSW;//TAC5112_20240926
	temp |= 0x8000;
//TAC5112_20240926	DMA0_CH1_TC_MSW = temp;
DMA1_CH1_TC_MSW = temp;//TAC5112_20240926

	return 0;
}
//################################################################################
//Uint16 set_dma1_ch2_i2s2_Lin(void)
Uint16 set_dma0_ch2_i2s0_Lin(void)
{
Uint16 temp; 

//TAC5112_20240926	DMA0_CH2_TC_LSW = XMIT_BUFF_SIZE*2;
DMA1_CH2_TC_LSW = XMIT_BUFF_SIZE*2;//TAC5112_20240926

//	DMA0_CH2_TC_MSW = 0x3084;     //src fix, destination increase, sync, auto, int 
//TAC5112_20240926	DMA0_CH2_TC_MSW = 0x2084;     //src fix, destination increase,, No auto, int
DMA1_CH2_TC_MSW = 0x2084;//TAC5112_20240926     //src fix, destination increase,, No auto, int

//TAC5112_20240926	temp = DMA0_CH32_EVENT_SRC;
temp = DMA1_CH32_EVENT_SRC;//TAC5112_20240926
//TAC5112_20240926	DMA0_CH32_EVENT_SRC = temp | 0x0002;   // I2S0 receive event
DMA1_CH32_EVENT_SRC = temp | 0x0002;//TAC5112_20240926   // I2S0 receive event

//TAC5112_20240926	DMA0_CH2_DST_LSW = (Uint16)RxL1_DMA_address;
DMA1_CH2_DST_LSW = (Uint16)RxL1_DMA_address;//TAC5112_20240926
//TAC5112_20240926	DMA0_CH2_DST_MSW = 0xFFFF & (RxL1_DMA_address >> 16);
DMA1_CH2_DST_MSW = 0xFFFF & (RxL1_DMA_address >> 16);//TAC5112_20240926
    
//TAC5112_20240803    DMA0_CH2_SRC_LSW = 0x2828;      // is22 receive left data register lsw
//TAC5112_20240926	DMA0_CH2_SRC_LSW = 0x2A28;      // i2s2 receive left data register lsw
DMA1_CH2_SRC_LSW = 0x2A28;//TAC5112_20240926      // i2s2 receive left data register lsw

//20140617 T.Okutsu	DMA0_CH2_SRC_LSW = 0x2A28;      // is22 receive left data register lsw
//TAC5112_20240926	DMA0_CH2_SRC_MSW = 0;
DMA1_CH2_SRC_MSW = 0;//TAC5112_20240926

	//CurrentRxL_DMAChannel =1;
//  DMA starts   
//TAC5112_20240926	temp = DMA0_CH2_TC_MSW;
temp = DMA1_CH2_TC_MSW;//TAC5112_20240926
	temp |= 0x8000;
//TAC5112_20240926	DMA0_CH2_TC_MSW = temp;
DMA1_CH2_TC_MSW = temp;//TAC5112_20240926

	return 0;
}
//################################################################################
//Uint16 set_dma1_ch3_i2s2_Rin(void)
Uint16 set_dma0_ch3_i2s0_Rin(void)
{
Uint16 temp; 

//TAC5112_20240926	DMA0_CH3_TC_LSW = XMIT_BUFF_SIZE*2;
DMA1_CH3_TC_LSW = XMIT_BUFF_SIZE*2;//TAC5112_20240926

//	DMA0_CH3_TC_MSW = 0x3084;     //src fix, destination increase, sync, auto , int
//TAC5112_20240926	DMA0_CH3_TC_MSW = 0x2084;     //src fix, destination increase,, No auto, int  
DMA1_CH3_TC_MSW = 0x2084;//TAC5112_20240926     //src fix, destination increase,, No auto, int  

//TAC5112_20240926	temp = DMA0_CH32_EVENT_SRC;
temp = DMA1_CH32_EVENT_SRC;//TAC5112_20240926
//TAC5112_20240926	DMA0_CH32_EVENT_SRC = temp | 0x0200;   // I2S2 receive event
DMA1_CH32_EVENT_SRC = temp | 0x0200;//TAC5112_20240926   // I2S2 receive event
    
//TAC5112_20240926	DMA0_CH3_DST_LSW = (Uint16)RxR1_DMA_address;
DMA1_CH3_DST_LSW = (Uint16)RxR1_DMA_address;//TAC5112_20240926
//TAC5112_20240926	DMA0_CH3_DST_MSW = 0xFFFF & (RxR1_DMA_address >> 16);
DMA1_CH3_DST_MSW = 0xFFFF & (RxR1_DMA_address >> 16);//TAC5112_20240926
    
//TAC5112_20240803    DMA0_CH3_SRC_LSW = 0x282C;      // is22 receive right data register lsw
//TAC5112_20240926	DMA0_CH3_SRC_LSW = 0x2A2C;      // i2s2 receive right data register lsw
DMA1_CH3_SRC_LSW = 0x2A2C;//TAC5112_20240926      // i2s2 receive right data register lsw

//20140617 T.Okutsu	DMA0_CH3_SRC_LSW = 0x2A2C;      // is22 receive right data register lsw
//TAC5112_20240926	DMA0_CH3_SRC_MSW = 0;
DMA1_CH3_SRC_MSW = 0;//TAC5112_20240926

	//CurrentRxR_DMAChannel =1;
//  DMA starts   
//TAC5112_20240926	temp = DMA0_CH3_TC_MSW;
temp = DMA1_CH3_TC_MSW;//TAC5112_20240926
	temp |= 0x8000;
//TAC5112_20240926	DMA0_CH3_TC_MSW = temp;
DMA1_CH3_TC_MSW = temp;//TAC5112_20240926

	return 0;
}
//################################################################################
void clear_DMA_int(void)
{
Uint16 temp;
	
	//DMA_MSK = 0x00F0;   // 0x1c31 enable DMA1 interrupts
	DMA_MSK = 0x0000;     // Tx-L and Tx-R only
	//DMA_IFR = 0xFFFF;     // 0x1c30 clear interrupt flags
    
//DMA0-CH0 stop
//20200417	temp = DMA1_CH0_TC_MSW;
//TAC5112_20240926	temp = DMA0_CH0_TC_MSW;
temp = DMA1_CH0_TC_MSW;//TAC5112_20240926
	temp &= 0x7FFF;
//20200417	DMA1_CH0_TC_MSW = temp;   
//TAC5112_20240926	DMA0_CH0_TC_MSW = temp;   
DMA1_CH0_TC_MSW = temp;//TAC5112_20240926   
	
//DMA0-CH1 stop
//20200417	temp = DMA1_CH1_TC_MSW;
//TAC5112_20240926	temp = DMA0_CH1_TC_MSW;
temp = DMA1_CH1_TC_MSW;//TAC5112_20240926
	temp &= 0x7FFF;
//20200417	DMA1_CH1_TC_MSW = temp;    
//TAC5112_20240926	DMA0_CH1_TC_MSW = temp;    
DMA1_CH1_TC_MSW = temp;//TAC5112_20240926    
//DMA0-CH2 stop
//20200417	temp = DMA1_CH0_TC_MSW;
//TAC5112_20240926	temp = DMA0_CH2_TC_MSW;
temp = DMA1_CH2_TC_MSW;//TAC5112_20240926
	temp &= 0x7FFF;
//20200417	DMA1_CH0_TC_MSW = temp;   
//TAC5112_20240926	DMA0_CH2_TC_MSW = temp;   
DMA1_CH2_TC_MSW = temp;//TAC5112_20240926   
	
//DMA0-CH3 stop
//20200417	temp = DMA1_CH1_TC_MSW;
//TAC5112_20240926	temp = DMA0_CH3_TC_MSW;
temp = DMA1_CH3_TC_MSW;//TAC5112_20240926
	temp &= 0x7FFF;
//20200417	DMA1_CH1_TC_MSW = temp;    
//TAC5112_20240926	DMA0_CH3_TC_MSW = temp;    
DMA1_CH3_TC_MSW = temp;//TAC5112_20240926    
	
//clear interrupt flags
	//20140617 T.Okutsu	DMA_IFR = 0x0010 | 0x0020;      

//20200417	DMA_IFR = 0x0050 | 0x00A0;      
	DMA_IFR = 0xFFFF;      

}
//****************************************************************************
void enable_dma_int(void)
{
	IER0 |= 0x0100;		// enable DMA Int.Enable bit(CPU Interrupt Enable Reg.)
	DMA_MSK = 0xFFFF;	// enable all interrupts(DMA Interrupt Mask Reg.)
	DMA_IFR = 0xFFFF;	// clear interrupt flags(DMA Interrupt Flag Reg.)
}
//****************************************************************************
void disable_dma_int(void)
{
	IER0 &= ~0x0100;	// disable DMA Int.Enable bit(CPU Interrupt Enable Reg.)
	DMA_MSK = 0;	// disable all interrupts(DMA Interrupt Mask Reg.)
	DMA_IFR = 0xFFFF;	// clear interrupt flags(DMA Interrupt Flag Reg.)
}
//****************************************************************************
void Tx_isr(void)
{
int i;
	for(i=0;i<100;i++){
		
	}
}
//****************************************************************************
// DMAMƂ̃R[obN֐̃vg^CvidvȐ錾Ij
void (*DmaCall_Frnt)(Uint16 dma_chan, Uint16 buffer_no_1, Uint16 buffer_no_2) = (void *)0;

interrupt void DMA_Isr(void)

{
/*20200317
	DMA_IFR = 0xFFFF;	// clear interrupt flags

	set_dma0_ch1_i2s0_Rout();//Ȃ? ch0iLjsRouto͂I
	set_dma0_ch0_i2s0_Lout();//Ȃ? ch0iLjsRouto͂I
20200317*/

/*20200317test*/
//$$$$$$$$$$ 20200317_Appended follows
//20200416	Uint16 temp,i;
Uint16 temp;
Uint16 dma_start;
//Uint32 dma_addr;	//DMA]AhX

	temp = IFR0;
	IFR0 = temp;  

	temp = DMA_IFR;
//    DMA_IFR = temp;     // clear interrupt flags

//dma_addr = (Uint32)XmitL_Sine_1K;
//dma_addr = (dma_addr<<1) + 0x10000;

/*20200318 Only for Sine Wave out test
TxL1_DMA_address = (Uint32)XmitR_Sine_2K;        
TxL1_DMA_address = (TxL1_DMA_address<<1) + 0x10000;	// change word address to byte address and add DARAM offset for DMA
TxL2_DMA_address = (Uint32)XmitR_Sine_2K;        
TxL2_DMA_address = (TxL2_DMA_address<<1) + 0x10000;	// change word address to byte address and add DARAM offset for DMA
20200318 Only for test*/

	    
//o͏
//TAC5112_20240930    if(temp&0x0001)
    if(temp&0x0010)//TAC5112_20240930
//20140616 T.Okutsu	if(temp&0x0010)
	{
		// DMA TxL interrupt (channel 0)
		OutputOperatingForL =1;        
		if(CurrentTxL_DMAChannel ==1)
		{
			CurrentTxL_DMAChannel =2;
//TAC5112_20240926			DMA0_CH0_SRC_LSW = (Uint16)TxL2_DMA_address;
DMA1_CH0_SRC_LSW = (Uint16)TxL2_DMA_address;//TAC5112_20240926
//TAC5112_20240926			DMA0_CH0_SRC_MSW = 0xFFFF & (TxL2_DMA_address >> 16);
DMA1_CH0_SRC_MSW = 0xFFFF & (TxL2_DMA_address >> 16);//TAC5112_20240926
		}
		else
		{
			CurrentTxL_DMAChannel =1;
//TAC5112_20240926			DMA0_CH0_SRC_LSW = (Uint16)TxL1_DMA_address;
DMA1_CH0_SRC_LSW = (Uint16)TxL1_DMA_address;//TAC5112_20240926
//TAC5112_20240926			DMA0_CH0_SRC_MSW = 0xFFFF & (TxL1_DMA_address >> 16);
DMA1_CH0_SRC_MSW = 0xFFFF & (TxL1_DMA_address >> 16);//TAC5112_20240926
		}
		
//TAC5112_20240930		DMA_IFR = 0x0001;     // clear interrupt flags
		DMA_IFR = 0x0010;//TAC5112_20240930     // clear interrupt flags
//20140616 T.Okutsu		DMA_IFR = 0x0010;     // clear interrupt flags
//TAC5112_20240926		dma_start = DMA0_CH0_TC_MSW;
dma_start = DMA1_CH0_TC_MSW;//TAC5112_20240926
	    dma_start |= 0x8000;
//TAC5112_20240926	    DMA0_CH0_TC_MSW = dma_start;
DMA1_CH0_TC_MSW = dma_start;//TAC5112_20240926
	}

//TAC5112_20240926	else if(temp&0x0002)
	else if(temp&0x0020)//TAC5112_20240926
//20140616 T.Okutsu	else if(temp&0x0020)
	{
		// DMA TxR interrupt (channel 1)
		OutputOperatingForR =1;        
		if(CurrentTxR_DMAChannel ==1)
		{
			CurrentTxR_DMAChannel =2;
//TAC5112_20240926			DMA0_CH1_SRC_LSW = (Uint16)TxR2_DMA_address;
DMA1_CH1_SRC_LSW = (Uint16)TxR2_DMA_address;//TAC5112_20240926
//TAC5112_20240926			DMA0_CH1_SRC_MSW = 0xFFFF & (TxR2_DMA_address >> 16);
DMA1_CH1_SRC_MSW = 0xFFFF & (TxR2_DMA_address >> 16);//TAC5112_20240926
		}
		else
		{
			CurrentTxR_DMAChannel =1;
//TAC5112_20240926			DMA0_CH1_SRC_LSW = (Uint16)TxR1_DMA_address;
DMA1_CH1_SRC_LSW = (Uint16)TxR1_DMA_address;//TAC5112_20240926
//TAC5112_20240926			DMA0_CH1_SRC_MSW = 0xFFFF & (TxR1_DMA_address >> 16);
DMA1_CH1_SRC_MSW = 0xFFFF & (TxR1_DMA_address >> 16);//TAC5112_20240926
		}
//TAC5112_20240930		DMA_IFR = 0x0002;     // clear interrupt flags        
		DMA_IFR = 0x0020;//TAC5112_20240930     // clear interrupt flags        
//20140616 T.Okutsu		DMA_IFR = 0x0020;     // clear interrupt flags        
//TAC5112_20240926		dma_start = DMA0_CH1_TC_MSW;
dma_start = DMA1_CH1_TC_MSW;//TAC5112_20240926
		dma_start |= 0x8000;
//TAC5112_20240926		DMA0_CH1_TC_MSW = dma_start;        
DMA1_CH1_TC_MSW = dma_start;//TAC5112_20240926        
	}
	
	//͏
//TAC5112_20240926	else if(temp&0x0004)
	else if(temp&0x0040)//TAC5112_20240926
//20140616 T.Okutsu	else if(temp&0x0040)
	{
		InputOperatingForL =1;        
		// DMA RxL interrupt (channel 2)
		if(CurrentRxL_DMAChannel ==1)
		{
			// change DMA Tx SRC address
			CurrentRxL_DMAChannel =2;
			
//TAC5112_20240926			DMA0_CH2_DST_LSW = (Uint16)RxL2_DMA_address;
DMA1_CH2_DST_LSW = (Uint16)RxL2_DMA_address;//TAC5112_20240926
//TAC5112_20240926			DMA0_CH2_DST_MSW = 0xFFFF & (RxL2_DMA_address >> 16);
DMA1_CH2_DST_MSW = 0xFFFF & (RxL2_DMA_address >> 16);//TAC5112_20240926
		}
		else
		{
			CurrentRxL_DMAChannel =1;
			
//TAC5112_20240926			DMA0_CH2_DST_LSW = (Uint16)RxL1_DMA_address;
DMA1_CH2_DST_LSW = (Uint16)RxL1_DMA_address;//TAC5112_20240926
//TAC5112_20240926			DMA0_CH2_DST_MSW = 0xFFFF & (RxL1_DMA_address >> 16);
DMA1_CH2_DST_MSW = 0xFFFF & (RxL1_DMA_address >> 16);//TAC5112_20240926
		}
//TAC5112_20240930		DMA_IFR = 0x0004;     // clear interrupt flags        
		DMA_IFR = 0x0040;//TAC5112_20240930     // clear interrupt flags        
//20140616 T.Okutsu		DMA_IFR = 0x0040;     // clear interrupt flags        
//TAC5112_20240926		dma_start = DMA0_CH2_TC_MSW;
dma_start = DMA1_CH2_TC_MSW;//TAC5112_20240926
		dma_start |= 0x8000;
//TAC5112_20240926		DMA0_CH2_TC_MSW = dma_start;        
DMA1_CH2_TC_MSW = dma_start;//TAC5112_20240926        
	}

//TAC5112_20240926	else if(temp&0x0008)
	else if(temp&0x0080)//TAC5112_20240926
//20140616 T.Okutsu	else if(temp&0x0080)
	{
		InputOperatingForR =1;                
		// DMA RxR interrupt (channel 3)
		if(CurrentRxR_DMAChannel ==1)
		{
			// change DMA Tx SRC address
			CurrentRxR_DMAChannel =2;
			
//TAC5112_20240926			DMA0_CH3_DST_LSW = (Uint16)RxR2_DMA_address;
DMA1_CH3_DST_LSW = (Uint16)RxR2_DMA_address;//TAC5112_20240926
//TAC5112_20240926			DMA0_CH3_DST_MSW = 0xFFFF & (RxR2_DMA_address >> 16);
DMA1_CH3_DST_MSW = 0xFFFF & (RxR2_DMA_address >> 16);//TAC5112_20240926
		}
		else
		{
			CurrentRxR_DMAChannel =1;
			
//TAC5112_20240926			DMA0_CH3_DST_LSW = (Uint16)RxR1_DMA_address;
DMA1_CH3_DST_LSW = (Uint16)RxR1_DMA_address;//TAC5112_20240926
//TAC5112_20240926			DMA0_CH3_DST_MSW = 0xFFFF & (RxR1_DMA_address >> 16);
DMA1_CH3_DST_MSW = 0xFFFF & (RxR1_DMA_address >> 16);//TAC5112_20240926
		}
//TAC5112_20240930		DMA_IFR = 0x0008;     // clear interrupt flags        
		DMA_IFR = 0x0080;//TAC5112_20240930     // clear interrupt flags        
//20140616 T.Okutsu		DMA_IFR = 0x0080;     // clear interrupt flags        
//TAC5112_20240926		dma_start = DMA0_CH3_TC_MSW;
dma_start = DMA1_CH3_TC_MSW;//TAC5112_20240926
		dma_start |= 0x8000;
//TAC5112_20240926		DMA0_CH3_TC_MSW = dma_start;        
DMA1_CH3_TC_MSW = dma_start;//TAC5112_20240926        
	}
//$$$$$$$$$$ 20200317_Appended above
/*20200317test*/


}
//****************************************************************************
//*                                                                          *
//*  main( )                                                                 *
//*                                                                          *
//****************************************************************************
void main( void )
{
int i, j;
	/* Initialize BSL */
	
Uint8* devdata;//20240925_TAC5112 Test
//20240925_TAC5112 Test Uint16* data;//20240925_TAC5112 Test
	
	//pll_init();
    ConfigPort();
    SYS_GlobalIntEnable();
    PLL_98MHz();

    /* Enable clocks to all peripherals */
    SYS_PCGCR1 = 0x0000;//{[h̪قւ̋CLK̐ݒB, eZDsp5535̏ꍇBSL̒EZDSP5535_init( )B
    SYS_PCGCR2 = 0x0000;//{[h̪قւ̋CLK̐ݒB, eZDsp5535̏ꍇBSL̒EZDSP5535_init( )B
	
	
	
	
//20241004_TAC5112	AIC3204_Init();		//DAC̏ݒB

//====================TAC5112 Read Test==========================
CODEC_Init();//20241021_CODEC Test

/*20241021 AIC3109 Test
// TEST Read TAC5112 Register 20240924
//20241004_TAC5112 	//TAC5112_rset( 1, 1 );//Reset TAC5112 20240924
TAC5112_rset( 1, 0 );//Reset TAC5112 20240924
code_TAC5112 = TAC5112_rget( 0x5 );//Read Reg. = 0x15<-OK! 20240924
//code_TAC5112 = TAC5112_rget( 0x6 );//Read Reg. = 0x55<-OK! 20240924
//code_TAC5112 = TAC5112_rget( 0xA );//Read Reg. = 0x32<-OK! 20240924
//code_TAC5112 = TAC5112_rget( 0x10 );//Read Reg. = 0x52<-OK! 20240924

TAC5112_rset( 0x7F, 0x00 );//Reset TAC5112 20240924
code_TAC5112 = TAC5112_rget( 0x7F );//Read Reg. = 0x15<-OK! 20240924

TAC5112_rset( 0x00, 0x00 );//Reset TAC5112 20240924
code_TAC5112 = TAC5112_rget( 0x00 );//Read Reg. = 0x15<-OK! 20240924

TAC5112_rset( 0x02, 0x09 );//Reset TAC5112 20240927
code_TAC5112 = TAC5112_rget( 0x02 );//Read Reg. = 0x15<-OK! 20240924

TAC5112_rset( 0x3E, 0x50 );//Reset TAC5112 20240927
code_TAC5112 = TAC5112_rget( 0x3E );//Read Reg. = 0x15<-OK! 20240924

TAC5112_rset( 0x40, 0x81 );//Reset TAC5112 20240927
code_TAC5112 = TAC5112_rget( 0x40 );//Read Reg. = 0x15<-OK! 20240924

//TAC5112_rset( 0x4C, 0x5C );//Reset TAC5112 20240927
TAC5112_rset( 0x4C, 0x2E );//Reset TAC5112 20240927
code_TAC5112 = TAC5112_rget( 0x4C );//Read Reg. = 0x15<-OK! 20240924

TAC5112_rset( 0x50, 0x08 );//Reset TAC5112 20240927
//TAC5112_rset( 0x50, 0x00 );//Reset TAC5112 20240927
code_TAC5112 = TAC5112_rget( 0x50 );//Read Reg. = 0x15<-OK! 20240924

TAC5112_rset( 0x76, 0xCC );//Reset TAC5112 20240927
//20241007_TAC5112_Test	TAC5112_rset( 0x76, 0x0C );//Reset TAC5112 20240927
code_TAC5112 = TAC5112_rget( 0x76 );//Read Reg. = 0x15<-OK! 20240924

TAC5112_rset( 0x78, 0xC0 );//Reset TAC5112 20240927
//20241009_TAC5112_TestTAC5112_rset( 0x78, 0x40 );//Reset TAC5112 20240927
code_TAC5112 = TAC5112_rget( 0x78 );//Read Reg. = 0x15<-OK! 20240924

TAC5112_rset( 0x79, 0x0C );//Reset TAC5112 20240927
code_TAC5112 = TAC5112_rget( 0x79 );//Read Reg. = 0x15<-OK! 20240924

TAC5112_rset( 0x7A, 0xF0 );//Reset TAC5112 20240927
code_TAC5112 = TAC5112_rget( 0x7A );//Read Reg. = 0x15<-OK! 20240924

TAC5112_rset( 0x1A, 0x40 );//Reset TAC5112 20240927
//TAC5112_rset( 0x1A, 0x41 );// 1slot offset TAC5112 20240927
code_TAC5112 = TAC5112_rget( 0x1A );//Read Reg. = 0x15<-OK! 20240924

	TAC5112_rset( 0x1C, 0x00 );//Reset TAC5112 20240927
	code_TAC5112 = TAC5112_rget( 0x1C );//Read Reg. = 0x15<-OK! 20240924

//20241008_TAC5112	TAC5112_rset( 0x1E, 0x2F );//Reset TAC5112 20240927
//20241008_TAC5112	code_TAC5112 = TAC5112_rget( 0x1E );//Read Reg. = 0x15<-OK! 20240924

//20241007_TAC5112_TesTAC5112_rset( 0x28, 0x21 );//Reset TAC5112 20240927
//20241007_TAC5112_Tescode_TAC5112 = TAC5112_rget( 0x28 );//Read Reg. = 0x15<-OK! 20240924

code_TAC5112 = TAC5112_rget( 0x3E );//Read Reg. = 0x15<-OK! 20240924
code_TAC5112 = TAC5112_rget( 0x40 );//Read Reg. = 0x15<-OK! 20240924

code_TAC5112 = TAC5112_rget( 0x37 );//Read Reg. = 0x15<-OK! 20240924
code_TAC5112 = TAC5112_rget( 0x3C );//Read Reg. = 0x15<-OK! 20240924
code_TAC5112 = TAC5112_rget( 0x3D );//Read Reg. = 0x15<-OK! 20240924

20241021 AIC3109 Test*/


//====================TAC5112 Read Test==========================

/*20241123_Test*/

//AIC3109_rset( 0x1E, 0x2F );//Reset AIC3109 20241021
AIC3109_rset( 0, 0x00 );//Set PAGE_0
AIC3109_rset( 1, 0x80 );//Reset CODEC
AIC3109_rset( 1, 0x00 );//Clear Reset


//%%% fsύX //################ MCLK Selection ##################
#if (PLL_98M ==1)
//20241119	AIC3109_rset( 2, 0xAA );//ADC:48kHz(fsREF)/6=8kHz, DAC:48kHz(fsREF)/6=8kHz
	AIC3109_rset( 2, 0x00 );//ADC:48kHz(fsREF)/1=48kHz, DAC:48kHz(fsREF)/1=48kHz
#elif (PLL_65M ==1)
	AIC3109_rset( 2, 0x88 );//ADC:40kHz(fsREF)/5=8kHz, DAC:40kHz(fsREF)/5=8kHz
//20241203_Test	AIC3109_rset( 2, 0xAA );//ADC:48kHz(fsREF)/6=8kHz, DAC:48kHz(fsREF)/6=8kHz
//20241120_Test	AIC3109_rset( 2, 0x44 );//ADC:48kHz(fsREF)/3=16kHz, DAC:48kHz(fsREF)/3=16kHz
//20241120_Test	AIC3109_rset( 2, 0x33 );//ADC:48kHz(fsREF)/1.5=32kHz, DAC:48kHz(fsREF)/1.5=32kHz
#endif

//20241122_test
//20241124	code_AIC3109 = AIC3109_rget( 0x02 );//Read Reg. = 3

//################ MCLK Selection ##################

	AIC3109_rset( 3, 0x91 );//PLL Enable, PLL_Q(NoUse)=0010, Pll P=1
//20241203	AIC3109_rset( 3, 0x81 );//PLL Enable, PLL_Q(NoUse)=0000, Pll P=1

//%%% fsύX //################ MCLK Selection ##################
#if (PLL_98M ==1)
//20231119	AIC3109_rset( 4, 0xC0 );//PLL_J=110000(48), bit1=bit0=0
	AIC3109_rset( 4, 0x20 );//PLL_J=001000(32), bit1=bit0=0
#elif (PLL_65M ==1)
//20241204$$$$$$$$$$$ $$$$$$$$$$ $$$$$$$$$$$
	AIC3109_rset( 4, 0x80 );//PLL_J=(32->0x20)<-(bit7-bit2)10|0000, bit1=bit0=0//MCLK=2.56MHz
//20241204$$$$$$$$$$$ $$$$$$$$$$ $$$$$$$$$$$
//20241203_Test	AIC3109_rset( 4, 0x30 );//PLL_J=110000(48), bit1=bit0=0 fs(REF)=256k x K(=J.D) x R / 2048 x P  K=48, R=8, P=1,䂦fs(REF)=48k
//20241121_Test	AIC3109_rset( 4, 0x18 );//PLL_J=011000(24), bit1=bit0=0 fs(REF)=512k x K(=J.D) x R / 2048 x P  K=24, R=8, P=1,䂦fs(REF)=48k
//20241120_Test	AIC3109_rset( 4, 0x0C );//PLL_J=001100(12), bit1=bit0=0 fs(REF)=1024k x K(=J.D) x R / 2048 x P  K=12, R=8, P=1,䂦fs(REF)=48k
#endif
//################ MCLK Selection ##################

AIC3109_rset( 5, 0x00 );//PLL_D=00000000(K=J.D̏_ȉ.0.9999)
AIC3109_rset( 6, 0x00 );//PLL_D=000000(K=J.D̏_ȉ.0.9999), bit1=bit0=00

//################ MCLK Selection ##################
//20241203_Test	AIC3109_rset( 7, 0x04 );//bit7=0-> fsREF=48kHz, DAC_Dual_Rate_Ctrl=Disable, DAC_DATA_Path_Ctrl_A=Disable, DAC_DATA_Path_Ctrl_B=10(RighttCH), bit2`bit0=0
	AIC3109_rset( 7, 0x08 );//bit7=0-> fsREF=48kHz, DAC_Dual_Rate_Ctrl=Disable, DAC_DATA_Path_Ctrl_A=Disable, DAC_DATA_Path_Ctrl_B=01(LeftCH), bit2`bit0=0
//20241118	AIC3109_rset( 7, 0x88 );//bit7=1-> fsREF=44.1kHz, DAC_Dual_Rate_Ctrl=Disable, DAC_DATA_Path_Ctrl_A=Disable, DAC_DATA_Path_Ctrl_B=01(LeftCH), bit2`bit0=0
//################ MCLK Selection ##################

AIC3109_rset( 8, 0x00 );//BCLKtoIn(=SlaveMode), WCKtoIn(=SlaveMode), SO<-Drv_NoChangeToHiImp, BCLK/WCLK_Drv_NoChangeToHiImp, bit3-bi0=0

AIC3109_rset( 9, 0x00 );//bit7-bit6=00(=I2S_Mode), bit5-bit4=00(=16bit), BCLK_Rate=0, DAC_ReSync=0, ADC_ReSync=0, Re_SyncMode=0

AIC3109_rset( 10, 0x00 );//I2S_SlotOFFSET=0
//20241203_Test	AIC3109_rset( 10, 0x01 );//I2S_SlotOFFSET=1

#if (PLL_98M ==1)
AIC3109_rset( 11, 0x02 );//bit7->ADC_OVF_FLG, bit6=0(reserved), bit5->DAC_OVF_FLG, bit4=(reserved), bit3-0:PLL_R=0010(=2)
#elif (PLL_65M ==1)
//20241203_Test	MCLK AIC3109_rset( 11, 0x08 );//bit7->ADC_OVF_FLG, bit6=0(reserved), bit5->DAC_OVF_FLG, bit4=(reserved), bit3-0:PLL_R=1000(=8)
AIC3109_rset( 11, 0x01 );//bit7->ADC_OVF_FLG, bit6=0(reserved), bit5->DAC_OVF_FLG, bit4=(reserved), bit3-0:PLL_R=0001(=1)
#endif

//20241025	AIC3109_rset( 12, 0x10 );//ADC_HPF->100Hz, 
AIC3109_rset( 12, 0x00 );//ADC_HPF->Disable, 

AIC3109_rset( 15, 0x00 );//AGC_PGA_MUTE:OFF, 
AIC3109_rset( 16, 0x00 );//PGA_AUX Mute:OFF, 

AIC3109_rset( 19, 0x84 );//MIC/LINE_1_Input_Lev_CTRL for ADC PGA=Differentioal_Mode, ADC_ch_PWR_UP 

AIC3109_rset( 21, 0x08 );//MIC/LINE_2_Input_Lev_CTRL for ADC PGA, 

AIC3109_rset( 37, 0x80 );//bit7:DAC Power CTRL, 

AIC3109_rset( 42, 0x64 );//DAC_DrvPowerOn_Delay, Drv_RampUp_StepTiming_CTRL, 
//20241024	AIC3109_rset( 43, 0x08 );//DAC_DigitalMute:OFF, DAC_DigVol_CTRL:0x08(-4dB?), 
AIC3109_rset( 43, 0x00 );//DAC_DigitalMute:OFF, DAC_DigVol_CTRL:0x00(0dB), 

//################ PGA_AUX_Route ##################
//20241101_Test AIC3109_rset( 81, 0x94 );//bit7:PGA_AUX_Route_ON, PGA_to_LEFT_LOP_VOL_CTRL->-10dB, 
//20241118 AIC3109_rset( 81, 0x80 );//bit7:PGA_AUX_Route_ON, PGA_to_LEFT_LOP_VOL_CTRL->0dB, 
//################ PGA_AUX_Route ##################

AIC3109_rset( 82, 0x80 );//bit7:DAC_1_Output_Routing_CTRL, DAC_1_to_LEFT_LOP/M Anlg_VOL_CTRL->0dB, 

AIC3109_rset( 86, 0x0D );//LEFT_LOP/M_OutLevCTRL LEFT_LOP/M_Mute:OFF, 

//################ MCLK Selection ##################
#if (PLL_98M ==1)
//20241127_Test	AIC3109_rset( 102, 0x00 );//CLKDIV_IN->MCLK, PLL_CLKIN->MCLK
	AIC3109_rset( 102, 0xA0 );//CLKDIV_IN->BCLK, PLL_CLKIN->BCLK
#elif (PLL_65M ==1)
	AIC3109_rset( 102, 0x00 );//CLKDIV_IN->MCLK, PLL_CLKIN->MCLK
//20241127_Test	AIC3109_rset( 102, 0xA0 );//CLKDIV_IN->BCLK, //ADC -> DAC OK!
#endif
//################ MCLK Selection ##################


//20241127_Test	AIC3109_rset( 107, 0x08 );//20241127 (SW-D1 ON!)Bit3-> ADC_DigOutput_Progmable Filter_Path_Sel


/*20241125*/
//Settled Reg.
code_AIC3109 = AIC3109_rget( 2 );//Read Reg. = 0xAA
code_AIC3109 = AIC3109_rget( 3 );//Read Reg. = 0x91
code_AIC3109 = AIC3109_rget( 4 );//Read Reg. = 0x30
code_AIC3109 = AIC3109_rget( 5 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 6 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 7 );//Read Reg. = 0x08
code_AIC3109 = AIC3109_rget( 8 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 9 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 10 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 11 );//Read Reg. = 0x08
code_AIC3109 = AIC3109_rget( 12 );//Read Reg. = 0x00 ADC_HPF(bit7,bit6), DAC_De-Emph_Filter(bit3,bit2)
code_AIC3109 = AIC3109_rget( 15 );//Read Reg. = 0x00 // ADC_MUTE, ADCPGA Gain
code_AIC3109 = AIC3109_rget( 16 );//Read Reg. = 0x00 // PGA_AUX, ADCPGA Gain
code_AIC3109 = AIC3109_rget( 19 );//Read Reg. = 0x84 // Mic1P/Line1P Input1 Lev Control
code_AIC3109 = AIC3109_rget( 21 );//Read Reg. = 0x08 // Mic2P/Line2P Input1 Lev Control
code_AIC3109 = AIC3109_rget( 37 );//Read Reg. = 0x80 // DAC PWR CTRL, ADC PWR STT, Sig.Det STT, AGC Saturation STT.
code_AIC3109 = AIC3109_rget( 42 );//Read Reg. = 0x64
code_AIC3109 = AIC3109_rget( 43 );//Read Reg. = 0x00 //DAC Dig.Volume CTRL
code_AIC3109 = AIC3109_rget( 82 );//Read Reg. = 0x80 //DAC1 to Left_LOP/M Ana Volume CTRL
code_AIC3109 = AIC3109_rget( 86 );//Read Reg. = 0x08 //Left_LOP/M Output Lev CTRL
code_AIC3109 = AIC3109_rget( 102 );//Read Reg. = 0xA0


//Non settled Reg.
code_AIC3109 = AIC3109_rget( 13 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 14 );//Read Reg. = 0x00
// Page0ɂ͂ȂIcode_AIC3109 = AIC3109_rget( 17 );//Read Reg. = 0x00
// Page0ɂ͂ȂIcode_AIC3109 = AIC3109_rget( 18 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 20 );//Read Reg. = 0x78
code_AIC3109 = AIC3109_rget( 22 );//Read Reg. = 0x78
// Page0ɂ͂ȂIcode_AIC3109 = AIC3109_rget( 23 );//Read Reg. = 0x0
// Page0ɂ͂ȂIcode_AIC3109 = AIC3109_rget( 24 );//Read Reg. = 0x0
code_AIC3109 = AIC3109_rget( 25 );//Read Reg. = 0x06
code_AIC3109 = AIC3109_rget( 26 );//Read Reg. = 0x00 // AGC Disable
code_AIC3109 = AIC3109_rget( 27 );//Read Reg. = 0xFE // AGC Max Gain Allowed
code_AIC3109 = AIC3109_rget( 28 );//Read Reg. = 0x00 //Noise Gate, AGC Clip Step Control
code_AIC3109 = AIC3109_rget( 29 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 30 );//Read Reg. = 0xFE
code_AIC3109 = AIC3109_rget( 31 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 32 );//Read Reg. = 0x80//Ch Gain Applied by AGC Algo.
code_AIC3109 = AIC3109_rget( 33 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 34 );//Read Reg. = 0x00// AGC Noise Detect Debounce CTRL
code_AIC3109 = AIC3109_rget( 35 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 36 );//Read Reg. = 0x00

code_AIC3109 = AIC3109_rget( 38 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 39 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 40 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 41 );//Read Reg. = 0x00

code_AIC3109 = AIC3109_rget( 44 );//Read Reg. = 0x80
code_AIC3109 = AIC3109_rget( 45 );//Read Reg. = 0x00

code_AIC3109 = AIC3109_rget( 51 );//Read Reg. = 0x04
code_AIC3109 = AIC3109_rget( 52 );//Read Reg. = 0x00

code_AIC3109 = AIC3109_rget( 58 );//Read Reg. = 0x04
code_AIC3109 = AIC3109_rget( 59 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 60 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 61 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 62 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 63 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 64 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 65 );//Read Reg. = 0x04
code_AIC3109 = AIC3109_rget( 66 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 67 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 68 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 69 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 70 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 71 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 72 );//Read Reg. = 0x04
code_AIC3109 = AIC3109_rget( 73 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 74 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 75 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 76 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 77 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 78 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 79 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 80 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 81 );//Read Reg. = 0x00 //PGA to Left LOP/M Ana Volume CTRL

code_AIC3109 = AIC3109_rget( 83 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 84 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 85 );//Read Reg. = 0x00

code_AIC3109 = AIC3109_rget( 87 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 88 );//Read Reg. = 0x00 //DAC1_Out Routing CTRL
code_AIC3109 = AIC3109_rget( 89 );//Read Reg. = 0x00 //DAC1 to Right_LOP/M Ana Volume CTRL
code_AIC3109 = AIC3109_rget( 90 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 91 );//Read Reg. = 0x00 //PGA_AUX to Right_LOP/M Ana Volume CTRL
code_AIC3109 = AIC3109_rget( 92 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 93 );//Read Reg. = 0x00 //Right_LOP/M Output Lev CTRL
code_AIC3109 = AIC3109_rget( 94 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 95 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 96 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 97 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 98 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 99 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 100 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 101 );//Read Reg. = 0x00

code_AIC3109 = AIC3109_rget( 103 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 104 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 105 );//Read Reg. = 0x00

code_AIC3109 = AIC3109_rget( 107 );//Read Reg. = 0x00  ADC_DigOutput_Progmable Filter_Path_Sel
code_AIC3109 = AIC3109_rget( 108 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 109 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 110 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 111 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 112 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 113 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 114 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 115 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 116 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 117 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 118 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 119 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 120 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 121 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 122 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 123 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 124 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 125 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 126 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 127 );//Read Reg. = 0x00


AIC3109_rset( 0, 0x01 );//Set PAGE_1

//20241128	AIC3109_rset( 65, 0x39 );//20241125 Set Coef to Default Value!
//20241128	code_AIC3109 = AIC3109_rget( 65 );//Read Reg. = should to be 0x39!


code_AIC3109 = AIC3109_rget( 0 );//Read Reg. = 0x01

code_AIC3109 = AIC3109_rget( 1 );//Read Reg. = 0x6B//Audio Eff Filter N0 Coef_MSB
code_AIC3109 = AIC3109_rget( 2 );//Read Reg. = 0xE3//Audio Eff Filter N0 Coef_LSB
code_AIC3109 = AIC3109_rget( 3 );//Read Reg. = 0x96//Audio Eff Filter N1 Coef_MSB
code_AIC3109 = AIC3109_rget( 4 );//Read Reg. = 0x66//Audio Eff Filter N1 Coef_LSB
code_AIC3109 = AIC3109_rget( 5 );//Read Reg. = 0x67//Audio Eff Filter N2 Coef_MSB
code_AIC3109 = AIC3109_rget( 6 );//Read Reg. = 0x5D//Audio Eff Filter N2 Coef_LSB
code_AIC3109 = AIC3109_rget( 7 );//Read Reg. = 0x6B//  Eff Filter Coef Under here
code_AIC3109 = AIC3109_rget( 8 );//Read Reg. = 0xE3
code_AIC3109 = AIC3109_rget( 9 );//Read Reg. = 0x96
code_AIC3109 = AIC3109_rget( 10 );//Read Reg. = 0x66
code_AIC3109 = AIC3109_rget( 11 );//Read Reg. = 0x67
code_AIC3109 = AIC3109_rget( 12 );//Read Reg. = 0x5D
code_AIC3109 = AIC3109_rget( 13 );//Read Reg. = 0x7D
code_AIC3109 = AIC3109_rget( 14 );//Read Reg. = 0x83
code_AIC3109 = AIC3109_rget( 15 );//Read Reg. = 0x84
code_AIC3109 = AIC3109_rget( 16 );//Read Reg. = 0xEE
code_AIC3109 = AIC3109_rget( 17 );//Read Reg. = 0x7D
code_AIC3109 = AIC3109_rget( 18 );//Read Reg. = 0x83
code_AIC3109 = AIC3109_rget( 19 );//Read Reg. = 0x84
code_AIC3109 = AIC3109_rget( 20 );//Read Reg. = 0xEE
code_AIC3109 = AIC3109_rget( 21 );//Read Reg. = 0x39
code_AIC3109 = AIC3109_rget( 22 );//Read Reg. = 0x55
code_AIC3109 = AIC3109_rget( 23 );//Read Reg. = 0xF3
code_AIC3109 = AIC3109_rget( 24 );//Read Reg. = 0x2D//  Eff Filter Coef Above here
code_AIC3109 = AIC3109_rget( 25 );//Read Reg. = 0x53//Audio Eff Filter N0 Coef_MSB
code_AIC3109 = AIC3109_rget( 26 );//Read Reg. = 0x7E//Audio Eff Filter N0 Coef_LSB
code_AIC3109 = AIC3109_rget( 27 );//Read Reg. = 0x6B//  Eff Filter Coef Under here
code_AIC3109 = AIC3109_rget( 28 );//Read Reg. = 0xE3
code_AIC3109 = AIC3109_rget( 29 );//Read Reg. = 0x96
code_AIC3109 = AIC3109_rget( 30 );//Read Reg. = 0x66
code_AIC3109 = AIC3109_rget( 31 );//Read Reg. = 0x67
code_AIC3109 = AIC3109_rget( 32 );//Read Reg. = 0x5D
code_AIC3109 = AIC3109_rget( 33 );//Read Reg. = 0x6B
code_AIC3109 = AIC3109_rget( 34 );//Read Reg. = 0xE3
code_AIC3109 = AIC3109_rget( 35 );//Read Reg. = 0x96
code_AIC3109 = AIC3109_rget( 36 );//Read Reg. = 0x66
code_AIC3109 = AIC3109_rget( 37 );//Read Reg. = 0x67
code_AIC3109 = AIC3109_rget( 38 );//Read Reg. = 0x5D
code_AIC3109 = AIC3109_rget( 39 );//Read Reg. = 0x7D
code_AIC3109 = AIC3109_rget( 40 );//Read Reg. = 0x83
code_AIC3109 = AIC3109_rget( 41 );//Read Reg. = 0x84
code_AIC3109 = AIC3109_rget( 42 );//Read Reg. = 0xEE
code_AIC3109 = AIC3109_rget( 43 );//Read Reg. = 0x7D
code_AIC3109 = AIC3109_rget( 44 );//Read Reg. = 0x83
code_AIC3109 = AIC3109_rget( 45 );//Read Reg. = 0x84
code_AIC3109 = AIC3109_rget( 46 );//Read Reg. = 0xEE
code_AIC3109 = AIC3109_rget( 47 );//Read Reg. = 0x39
code_AIC3109 = AIC3109_rget( 48 );//Read Reg. = 0x55
code_AIC3109 = AIC3109_rget( 49 );//Read Reg. = 0xF3
code_AIC3109 = AIC3109_rget( 50 );//Read Reg. = 0x2D
code_AIC3109 = AIC3109_rget( 51 );//Read Reg. = 0x53
code_AIC3109 = AIC3109_rget( 52 );//Read Reg. = 0x7E
code_AIC3109 = AIC3109_rget( 53 );//Read Reg. = 0x7F
code_AIC3109 = AIC3109_rget( 54 );//Read Reg. = 0xFF
code_AIC3109 = AIC3109_rget( 55 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 56 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 57 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 58 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 59 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 60 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 61 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 62 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 63 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 64 );//Read Reg. = 0x00//  Eff Filter Coef Above here
code_AIC3109 = AIC3109_rget( 65 );//Read Reg. = 0x39//ADC HPF N0 Coef_MSB // v`FbNI0x39ƏĂ0x7FɂȂĂ܂I
code_AIC3109 = AIC3109_rget( 66 );//Read Reg. = 0xEA//ADC HPF N0 Coef_LSB
code_AIC3109 = AIC3109_rget( 67 );//Read Reg. = 0x80//   :
code_AIC3109 = AIC3109_rget( 68 );//Read Reg. = 0x16//   :
code_AIC3109 = AIC3109_rget( 69 );//Read Reg. = 0x7F//ADC HPF N0 Coef_MSB
code_AIC3109 = AIC3109_rget( 70 );//Read Reg. = 0xD5//ADC HPF N0 Coef_LSB
code_AIC3109 = AIC3109_rget( 71 );//Read Reg. = 0x7F//Reserved from here
code_AIC3109 = AIC3109_rget( 72 );//Read Reg. = 0xEA
code_AIC3109 = AIC3109_rget( 73 );//Read Reg. = 0x80
code_AIC3109 = AIC3109_rget( 74 );//Read Reg. = 0x16
code_AIC3109 = AIC3109_rget( 75 );//Read Reg. = 0x7F
code_AIC3109 = AIC3109_rget( 76 );//Read Reg. = 0xD5
code_AIC3109 = AIC3109_rget( 77 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 78 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 80 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 81 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 82 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 83 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 84 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 85 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 86 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 87 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 88 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 89 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 90 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 91 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 92 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 93 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 94 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 95 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 96 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 97 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 98 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 99 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 100 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 101 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 102 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 103 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 104 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 105 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 106 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 107 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 108 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 109 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 110 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 111 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 112 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 113 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 114 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 115 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 116 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 117 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 118 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 119 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 120 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 121 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 122 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 123 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 124 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 125 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 126 );//Read Reg. = 0x00
code_AIC3109 = AIC3109_rget( 127 );//Read Reg. = 0x00

/*20241125*/


//20241022 for I2C_ERR test read code_AIC3109 = AIC3109_rget( 106 );//REG.107I2CXe[^XI@ǂ݂REGAhX-1Ďw肷I

/*20241123_Test*/

/*20241122
code_AIC3109 = AIC3109_rget( 0x01 );//ǂ݂REGAhX-1Ďw肷I
code_AIC3109 = AIC3109_rget( 0x02 );//Read Reg. = 3

//20241022	AIC3109_rset( 0x04, 0xC0 );//Read Reg. = 
code_AIC3109 = AIC3109_rget( 0x03 );//ǂ݂REGAhX-1Ďw肷I

//20241022	AIC3109_rset( 0x05, 0x3F );//Read Reg. = 
//20241022	AIC3109_rset( 0x06, 0x54 );//Read Reg. = 
code_AIC3109 = AIC3109_rget( 0x05 );//ǂ݂REGAhX-1Ďw肷I



code_AIC3109 = AIC3109_rget( 0x02 );//ǂ݂REGAhX-1Ďw肷I
code_AIC3109 = AIC3109_rget( 0x03 );//ǂ݂REGAhX-1Ďw肷I
20241122*/

/*20241021
code_AIC3109 = AIC3109_rget( 0x00 );//Read Reg. = 
AIC3109_rset( 0x00, 0x00 );//Write Reg. = 
20241021*/	
	
/*20241123
	AIC3204_rset( 0, 0 );		// Select page 1
	AIC3204_rset( 1, 1 );		// Reset codec
	AIC3204_rset( 0, 1 );		// Point to page 1
	AIC3204_rset( 1, 8 );		// Disable crude AVDD generation from DVDD
	AIC3204_rset( 2, 1 );		// Enable Analog Blocks, use LDO power
	AIC3204_rset( 0, 0 );
	// PLL and Clocks config and Power Up
	AIC3204_rset( 27, 0x0d );	// BCLK and WCLK is set as o/p to AIC3204(Master)
	AIC3204_rset( 28, 0x00 );	// Data ofset = 0

code_AIC3204 = AIC3204_rget( 27 );	// 20241123


	AIC3204_rset( 4, 3 );		// PLL setting: PLLCLK <- MCLK, CODEC_CLKIN <-PLL CLK
	AIC3204_rset( 6, 8 );		// PLL setting: J=8
	AIC3204_rset( 7, 15 );		// PLL setting: HI_BYTE(D)
	AIC3204_rset( 8, 0xdc ); 	// PLL setting: LO_BYTE(D)
	AIC3204_rset( 30, 0x88 );	// For 32 bit clocks per frame in Master mode ONLY

code_AIC3204 = AIC3204_rget( 4 );	// 20241123
code_AIC3204 = AIC3204_rget( 6 );	// 20241123
code_AIC3204 = AIC3204_rget( 7 );	// 20241123
code_AIC3204 = AIC3204_rget( 8 );	// 20241123
code_AIC3204 = AIC3204_rget( 30 );	// 20241123

code_AIC3204 = AIC3204_rget( 1 );	// 20241123
code_AIC3204 = AIC3204_rget( 2 );	// 20241123
20241123*/
	
	IER0 &= ~0x0020;	// disable _Tx_Isr Int.Enable bit(CPU Interrupt Enable Reg.)//20200416
	

	disable_dma_int();	//DMA݋BiSchɂāj//20200414

//20200317 Appended follows
	CurrentTxL_DMAChannel =2;
	CurrentTxR_DMAChannel =2;
	CurrentRxL_DMAChannel =2;
	CurrentRxR_DMAChannel =2;
	InputOperatingForL =1;
	InputOperatingForR =0;
	OutputOperatingForL =1;
	OutputOperatingForR =0;
	
	setDMA_address();


	disable_dma_int();	//DMA݋BiSchɂāj
	clear_DMA_int();//20200417
	USBSTK5505_waitusec( 300 );//20200422

	set_dma0_ch3_i2s0_Rin();
	set_dma0_ch2_i2s0_Lin();
	set_dma0_ch1_i2s0_Rout();
	set_dma0_ch0_i2s0_Lout();

	enable_dma_int();	//DMA݋BiSchɂāj
	
	I2S_Start();
	

	
	while(1)
	{
/*20200430
		//DMA݂hLgꍇ
		//Lch͂ꍇ̏
		if(InputOperatingForL ==1){//DMA0_ch2iLch́jɃf[^ĂhLgꍇAAA
			InputOperatingForL =0;
			if (CurrentRxL_DMAChannel ==2){
//20140617				buff_copy(&RcvL1[0],&TrsL1[0], XMIT_BUFF_SIZE);
//20140617 T.Okutsu				buff_copy(sinetbl, &TrsL1[0], XMIT_BUFF_SIZE);
//20200420				HPFilter(&RcvL1[0],&TrsL1[0], XMIT_BUFF_SIZE, LEFTCH);
				for(i=0;i<XMIT_BUFF_SIZE;i++){
//20200418test	TrsLchBuff_1[i] = RcvL1[i];//20200416test
				}
//20240930_TAC5112	buff_copy(XmitL_Sine_1K, &TrsL1[0], XMIT_BUFF_SIZE);//20240930_TAC5112
//20240930_TAC5112	buff_copy(XmitL_Sine_1K, &TrsR1[0], XMIT_BUFF_SIZE);//20240930_TAC5112
			}
			else{
//20140617				buff_copy(&RcvL2[0],&TrsL2[0], XMIT_BUFF_SIZE);
//20140617 T.Okutsu				buff_copy(sinetbl,&TrsL2[0], XMIT_BUFF_SIZE);
//20200420				HPFilter(&RcvL2[0],&TrsL2[0], XMIT_BUFF_SIZE, LEFTCH);
				for(i=0;i<XMIT_BUFF_SIZE;i++){
//20200418test	TrsLchBuff_2[i] = RcvL2[i];//20200416test
				}
//20240930_TAC5112	buff_copy(XmitL_Sine_1K, &TrsL2[0], XMIT_BUFF_SIZE);//20240930_TAC5112
//20240930_TAC5112	buff_copy(XmitL_Sine_1K, &TrsR2[0], XMIT_BUFF_SIZE);//20240930_TAC5112
			}
		}
20200430*///20240930_TAC5112 
		
		//Rch͂ꍇ̏
//20241118		if(InputOperatingForR ==1){//DMA0_ch3iRch́jɃf[^ĂhLgꍇAAA
//20241118			InputOperatingForR =0;
//20241118			if (CurrentRxR_DMAChannel ==2){

/*20241127*/
		//Lch͂ꍇ̏
		if(InputOperatingForL ==1){//DMA0_ch3iLch́jɃf[^ĂhLgꍇAAA
			InputOperatingForL =0;
			if (CurrentRxL_DMAChannel ==2){
/*20241127*/
			
/*20241127
		//Lcho̓CxgNꍇ̏
		if(OutputOperatingForL ==1){//DMA1_ch0iLchójɃf[^ȂȂhLgꍇAAA
			OutputOperatingForL =0;
			if (CurrentTxL_DMAChannel ==2){
20241127*/


//20140617				buff_copy(&RcvR1[0],&TrsR1[0], XMIT_BUFF_SIZE);
//20140617 T.Okutsu					buff_copy(sinetbl, &TrsR1[0], XMIT_BUFF_SIZE);
//20200420					HPFilter(&RcvR1[0],&TrsR1[0], XMIT_BUFF_SIZE, RIGHTCH);

/*20240930_TAC5112*/
				for(i=0;i<XMIT_BUFF_SIZE;i++){
					EchoFx((short)RcvL1[i]);//̪āi32bitjʂްi32bitŁjgMix_L/R,gDelayOut_L/Rɓ͂B
//20241010_TAC5112					TrsL1[i] = gMix_L;
//20241010_TAC5112					TrsR1[i] = gMix_R;

					TrsL1[i] = RcvL1[i];//́o̓oCpX
					TrsR1[i] = RcvL1[i];//́o̓oCpX
					
//20241002_TAC5112	TrsL1[i] = 0xA55A;//20241002_TAC5112
//20241002_TAC5112	TrsR1[i] = 0xA55A;//20241002_TAC5112
//20241008_TAC5112	TrsL1[i] = 0x7FFF;//20241002_TAC5112
//20241008_TAC5112	TrsR1[i] = 0x8000;//20241002_TAC5112
//20241009_TAC5112	if(i<=16348){TrsL1[i]=TrsL1[i-1]+340;} else {TrsL1[i]=-16384;}//20241008_TAC5112
//20241009_TAC5112	if(i<=16348){TrsR1[i]=TrsR1[i-1]+340;} else {TrsR1[i]=-16384;}//20241008_TAC5112

//20241204	TrsL1[i] = XmitR_Sine_2Kat8KHz[i];//20241022_AIC3109
//20241204	TrsR1[i] = XmitR_Sine_2Kat8KHz[i];//20241022_AIC3109
//20241129	TrsL1[i] = XmitR_Sine_1K[i];//20241022_AIC3109
//20241129	TrsR1[i] = XmitR_Sine_1K[i];//20241022_AIC3109

				}
				
/*20240930_TAC5112*/
//20240930_TAC5112	buff_copy(XmitL_Sine_1K, &TrsL1[0], XMIT_BUFF_SIZE);//20240930_TAC5112
//20240930_TAC5112	buff_copy(XmitL_Sine_1K, &TrsR1[0], XMIT_BUFF_SIZE);//20240930_TAC5112

			}
			else{
//20140617				buff_copy(&RcvR2[0],&TrsR2[0], XMIT_BUFF_SIZE);
//20140617 T.Okutsu					buff_copy(sinetbl, &TrsR2[0], XMIT_BUFF_SIZE);
//20200420					HPFilter(&RcvR2[0],&TrsR2[0], XMIT_BUFF_SIZE, RIGHTCH);

/*20240930_TAC5112*///20240930_TAC5112
				for(i=0;i<XMIT_BUFF_SIZE;i++){
					EchoFx((short)RcvL2[i]);//̪āi32bitjʂްi32bitŁjgMix_L/R,gDelayOut_L/Rɓ͂B
//20241010_TAC5112					TrsL2[i] = gMix_L;
//20241010_TAC5112					TrsR2[i] = gMix_R;

					TrsL2[i] = RcvL2[i];//́o̓oCpX
					TrsR2[i] = RcvL2[i];//́o̓oCpX
					
//20241002_TAC5112	TrsL2[i] = 0xA55A;//20241002_TAC5112
//20241008_TAC5112	TrsL2[i] = 0x7FFF;//20241002_TAC5112
//20241008_TAC5112	TrsR2[i] = 0x8000;//20241002_TAC5112
//20241002_TAC5112	TrsR2[i] = 0xA55A;//20241002_TAC5112
//20241009_TAC5112	if(i<=16348){TrsL2[i]=TrsL2[i-1]+340;} else {TrsL2[i]=-16384;}//20241008_TAC5112
//20241009_TAC5112	if(i<=16348){TrsR2[i]=TrsR2[i-1]+340;} else {TrsR2[i]=-16384;}//20241008_TAC5112

//20241204	TrsL2[i] = XmitR_Sine_2Kat8KHz[i];//20241022_AIC3109
//20241204	TrsR2[i] = XmitR_Sine_2Kat8KHz[i];//20241022_AIC3109
//20241129	TrsL2[i] = XmitR_Sine_1K[i];//20241022_AIC3109
//20241129	TrsR2[i] = XmitR_Sine_1K[i];//20241022_AIC3109

				}
				
/*20240930_TAC5112*///20240930_TAC5112
//20240930_TAC5112	buff_copy(XmitL_Sine_1K, &TrsL2[0], XMIT_BUFF_SIZE);//20240930_TAC5112
//20240930_TAC5112	buff_copy(XmitL_Sine_1K, &TrsR2[0], XMIT_BUFF_SIZE);//20240930_TAC5112

//20240930_TAC5112	for only test 	code_TAC5112 = TAC5112_rget( 0x1A );//Read Reg. = 0x15<-OK! 20241004
			}
		}
	}
}
//****************************************************************************
void buff_copy(Int16 *input, Int16 *output, Int16 size)
{
	Int16 i;
	
	for(i =0; i<size; i++)
	{
		*(output + i) = *(input +i);
	}
	
}
//****************************************************************************
void EchoFx(short Src)//̪āB
{
	gMix_L = Src;
	gMix_R = Src;
}
//********************************* EOF **************************************
