//////////////////////////////////////////////////////////////////////////////
// * File name: spirom_test.c
// *                                                                          
// * Description:  SPI ROM test.
// *                                                                          
// * Copyright (C) 2010 Texas Instruments Incorporated - http://www.ti.com/ 
// * Copyright (C) 2010 Spectrum Digital, Incorporated
// *                                                                          
// *                                                                          
// *  Redistribution and use in source and binary forms, with or without      
// *  modification, are permitted provided that the following conditions      
// *  are met:                                                                
// *                                                                          
// *    Redistributions of source code must retain the above copyright        
// *    notice, this list of conditions and the following disclaimer.         
// *                                                                          
// *    Redistributions in binary form must reproduce the above copyright     
// *    notice, this list of conditions and the following disclaimer in the   
// *    documentation and/or other materials provided with the                
// *    distribution.                                                         
// *                                                                          
// *    Neither the name of Texas Instruments Incorporated nor the names of   
// *    its contributors may be used to endorse or promote products derived   
// *    from this software without specific prior written permission.         
// *                                                                          
// *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS     
// *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT       
// *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR   
// *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT    
// *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,   
// *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT        
// *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,   
// *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY   
// *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT     
// *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE   
// *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.    
// *                                                                          
//////////////////////////////////////////////////////////////////////////////

#include "usbstk5505.h"
#include "usbstk5505_spirom.h"
#include "csl_spi.h"
#include "stdio.h"

static Uint8 tx[spirom_PAGESIZE];
static Uint8 rx[spirom_PAGESIZE];

/*
 *
 *  spirom_test( )
 *      SPI ROM test, write then verify the contents of the first 5 pages
 *
 */
Int16 spirom_test( )
{
    Int16 i, j, error = 0;
    Uint16* pdata;

    /* Initialize the SPI interface */
    if(USBSTK5505_SPIROM_init())
    {
        printf("SPIROM initialiation failed.\n");
        return 1;
    }

    /* Write to spirom */
    for ( i = 0 ; i < 5 ; i++ )
    {
        /* Create the test pattern */
        pdata = ( Uint16* )tx;
        for ( j = 0 ; j < spirom_PAGESIZE ; j++ )
            *pdata++ = ( Uint8 )( j + i + 2 );
            
        /* Write a page */
        if(USBSTK5505_SPIROM_write( ( Uint32 )tx, i * spirom_PAGESIZE, spirom_PAGESIZE ))
        {
            printf("SPIROM write fail.\n");
            return 1;
        }
    }

    /* Read and verify spirom */
    for ( i = 0 ; i < 5 ; i++ )
    {
        /* Clear receive buffer */
        for ( j = 0 ; j < spirom_PAGESIZE ; j++ )
            rx[j] = 0;
            
        /* Read a page */
        if(USBSTK5505_SPIROM_read( i * spirom_PAGESIZE, ( Uint32 )rx, spirom_PAGESIZE ))
        {
            printf("SPIROM read fail.\n");
            return 1;
        }
        
        /* Check the pattern */
        error = 0;
        pdata = ( Uint16* )rx;
        for ( j = 0 ; j < spirom_PAGESIZE ; j++ )
            if ( ( *pdata++ ) != ( Uint16 )( i + j + 2 ) )
                error ++;  // Fail
        if(error)
        {
            printf("Error on page %d", i);
            return 1;
        }
    }
    
    return 0;
}

